<?php
/*
--------------------------------------------------------------------------
This file is part of the WP Events Calendar project.

For questions, help, comments, discussion, etc., please join our
forum at {@link http://www.wp-eventscalendar.com/forum}. You can
also go to Luke's ({@link http://www.lukehowelll.com}) and
Heirem's ({@link http://heirem.fr}) blogs.

WP Events Calendar is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.   See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
--------------------------------------------------------------------------
*/

/**
 * This file contains the WP Events Calendar Administrator Large Calendar Manager class.
 *
 * @internal      Long description to be done. Or maybe we don't need it
 *                since we the class will be commented.
 *
 * @package       WP-Events-Calendar
 * @subpackage    Core
 * @author
 *                - Luke Howell <luke@wp-eventscalendar.com>
 *                - Brad Bodine <brad@wp-eventscalendar.com>
 *                - Ren MALKA <heirem@wp-eventscalendar.com>
 * @link
 *                - http://wp-eventscalendar.com/
 *                - http://www.lukehowell.com
 *                - http://myboxtool.com/
 *                - http://heirem.fr
 *                - http://laplix.com
 *                - http://www.gwathneydesign.com/
 * @since         7.0.0
 * @copyright
 *                - Copyright (c) 2007-2009 Luke Howell
 *                - Copyright (c) 2007-2009 Brad Bodine
 *                - Copyright (c) 2008-2009 Ren Malka
 *                - Copyright (c)      2009 Louis Lapointe
 *                - Copyright (c)      2009 Coe Gwathney
 * @license       GPLv3 {@link http://www.gnu.org/licenses/gpl}
 * @filesource
 *
 */

if(!class_exists("EC_ACalendar")) :

/**
 * Display and manage the Large Calendar for the administrator
 *
 * @internal Long description to be done.
 *
 * @package       WP-Events-Calendar
 * @subpackage    Core
 * @since         7.0.0
 */
class EC_ACalendar {

   /**
    * Constructor.
    * Loads the layout.
    * @access public
    */
    function EC_ACalendar() {
      // Get the current user rights
      wpec_usercan($this);
    }
	/**
    * Displays the Admin Calendar
    *
    * @param int     $year             year to display
    * @patam int     $month            month to display
    * @param array   $days             not used
    * param int      $day_name_lengh   length of days name. Not used. Defaults to 7.
    *
    * @global array                    the week days names
    * @global array                    the months names
    */
	function displayAdmin($year, $month) {
	  global $ec_WeekdayNames , $ec_WeekdayNamesAbbrev, $ec_MonthNames, $ec_MonthNamesAbbrev;
    // Capabilities : must be a string for js
    $user_login = $this->user_login;
    $can_update = $this->user_rights[2] ? 'true' :  'false';
    $can_delete = $this->user_rights[3] ? 'true' :  'false';
    $can_owner_update = $this->user_rights[4] ? 'true' :  'false';
    $can_owner_delete = $this->user_rights[5] ? 'true' :  'false';
    // set the arguments to the current date if empty
    $month = $month ? $month : date('m');
    $year  = $year  ? $year  : date('Y');
    // Get the general options
    wpec_get_option($this,'wpecOptionsGenSet');
    // Option : time format
    $tttf = explode('=',$this->ecopt_tttf); $tttf = $tttf[1];
    // Option : nb of weeks is fixed or not : true by default / must be a string for js options!
    $fixedWeeks = isset($this->ecopt_acfw) ? 'true' : 'false';
    // Option : define the event types priority display on the event recurrences / must be a string for js options!
    $typePriority = isset($this->ecopt_acpt) ? 'true' : 'false';
    // Option : Show time before events titles / must be a string for js options!
    $showtime = isset($this->ecopt_acst) ? '"guess"' : 'false';
    // Weekend days
    $weekends = $this->ecopt_weopt;
    switch ($weekends) {
    case 'ecopt_wesun':
      $str_we = array(strtolower($ec_WeekdayNamesAbbrev[5]),strtolower($ec_WeekdayNamesAbbrev[6]));
      $nb_we = array(5,6);
      break;
    case 'ecopt_wecust':
      $str_we = explode('-',$this->ecopt_cwe);
      $str_we[1] = is_null($str_we[1]) ?  'none' : $str_we[1];
      $flip_we =  array_flip($ec_WeekdayNamesAbbrev);
      $nb_we = array($flip_we[$str_we[0]],$flip_we[$str_we[1]]);
      $nb_we[1] = is_null($nb_we[1]) ?  10 : $nb_we[1];
      $str_we[0] = strtolower($str_we[0]); $str_we[1] = strtolower($str_we[1]);
      break;
    // default = 'ecopt_weuni' Universal Weekend days
    default:
      $str_we = array(strtolower($ec_WeekdayNamesAbbrev[6]),strtolower($ec_WeekdayNamesAbbrev[0]));
      $nb_we = array(6,0);
      break;
    }
    // Get list of colors Events Type
    wpec_get_option($this,'wpecOptionsEv');
    $enableRec = isset($this->ecopt_ev_recc);
    $recColors = $recLabel = array();
    if($enableRec) {
      $strEnableRec = 'true';
      for($i=0;$i<9;$i++) {
        $varRec = 'ecopt_ev_rec'.$i;
        $recColors[$i] = $this->$varRec;
        $recLabel[$i] = wpec_recLabel($i);
      }
    } else $strEnableRec = 'false';
    $eventIdTypes = $eventTypes = $colorTypes = array();
    $enableTypes = isset($this->ecopt_ev_types);
    if($enableTypes) {
      $enableEventTypes = 'true';
      wpec_get_option($this,'wpecOptionsTypes');
      $this->typesList = mb_unserialize(stripslashes($this->ecopt_sertypes));
      $colorTypesFlag = ($this->typesList != false);
      if($colorTypesFlag) {
        for($i=0;$i<count($this->typesList);$i++) {
          $eventIdTypes[$i] = $this->typesList[$i]['tid'];
          $eventTypes[$i] = $this->typesList[$i]['des'];
          $colorTypes[$i] = $this->typesList[$i]['col'];
        }
      } else $enableEventTypes = 'false';
    } else $enableEventTypes = 'false';
?>
<script type='text/javascript'>
jQuery.noConflict();
 (function($) {
   var user_login = "<?php echo $user_login;?>",
       can_update = <?php echo $can_update;?>,
       can_delete = <?php echo $can_delete;?>,
       can_owner_update = <?php echo $can_owner_update;?>,
       can_owner_delete = <?php echo $can_owner_delete;?>,
       imgPath = "<?php echo EVENTSCALENDARIMAGESURL;?>",
       delConfMsg = "<?php _e('Are you sure you want to delete the following event:\n','events-calendar');?>",
       excConfMsg = "<?php _e('Are you sure you want to re activate this recurrence?','events-calendar');?>",
       canConfMsg = "<?php _e('Are you sure you want to cancel this recurrence?','events-calendar');?>",
       delConfTitle = "<?php _e('Event Delete Confirmation','events-calendar');?>",
       excConfTitle = "<?php _e('Exception Activation Confirmation','events-calendar');?>",
       canConfTitle = "<?php _e('Cancellation Recurrence Confirmation','events-calendar');?>",
       enableEventTypes = <?php echo $enableEventTypes;?>,
       enableRec = <?php echo $strEnableRec;?>,
       weekends = "td:not(.other-month).<?php echo implode(', td:not(.other-month).',$str_we);?>";

   if(enableEventTypes) {
      var eventIdTypes = ['<?php echo implode("','",$eventIdTypes);?>'],
           eventTypes = ['<?php echo implode("','",$eventTypes);?>'],
           colorTypes = ['<?php echo implode("','",$colorTypes);?>'],
           arrayTypes = zip2(eventIdTypes,eventTypes,colorTypes);
   }

   if(enableRec) {
      var recColors = ['<?php echo implode("','",$recColors);?>'],
          recLabel = ['<?php echo implode("','",$recLabel);?>'];
   }

   typePriority = (enableEventTypes && enableRec) ? <?php echo $typePriority;?> : false;

   $.alerts.okButton = "<?php _e('Yes','events-calendar');?>"
   $.alerts.cancelButton = "<?php _e('Cancel','events-calendar');?>"
   $(document).ready(function() {
    $.fullCalendar.monthNames = ['<?php echo implode("','",$ec_MonthNames);?>'];
    $.fullCalendar.monthAbbrevs = ['<?php echo implode("','",$ec_MonthNamesAbbrev);?>'];
    $.fullCalendar.dayNames = ['<?php echo implode("','",$ec_WeekdayNames);?>'];
    $.fullCalendar.dayAbbrevs = ['<?php echo implode("','",$ec_WeekdayNamesAbbrev);?>'];
    $.fullCalendar.prevMonthsLabel = "<?php _e('Previous Months','events-calendar');?>";
    $.fullCalendar.nextMonthsLabel = "<?php _e('Next Months','events-calendar');?>";

    function processEventTypes(event, element) {
      if(in_array(event.type, eventIdTypes) && event.type !== 'evt0') {
        var typewitness = $("<img src='"+imgPath+"/typewitness.png' class='typewitness'/>")
          .attr('title',(arrayTypes[event.type][0]+''))
          .css('background-color',(arrayTypes[event.type][1]+''))
          .prependTo($(element).find('td.w'));
      }
    }

    function processTypeWitness(element, label, bgcolor) {
      var typewitness = $("<img src='"+imgPath+"/typewitness.png' class='typewitness'/>")
        .attr('title',label)
        .css('background-color',bgcolor)
        .prependTo($(element).find('td.w'));
    }

    function processRec(event, element) {
      if(event.rec > 0 && recColors[event.rec] != '' && $(element).attr('class').indexOf('recStart') < 0 && $(element).attr('class').indexOf('recEnd') < 0 ) {
        $(element).find('td.c')
          .css({'background-color':(recColors[event.rec]+''),'color':(recColors[event.rec].contrastColor())});
        $(element).find('td.w')
          .css('background-color',(recColors[event.rec]+''));
      }
    }

    function processBgEvent(element, bgcolor) {
      $(element).find('td.c').css({'background-color':bgcolor,'color':(bgcolor.contrastColor())});
      $(element).find('td.w').css('background-color',bgcolor);
    }

    function processIconsEvent(event, element){
      if(event.rec > 0) {
        if( $(element).attr('class').indexOf('recStart') > 0 || $(element).attr('class').indexOf('recEnd') > 0) {
          var delTitle = "<?php _e('Event delete','events-calendar');?>",
              icondel = "trash.png", classdel = 'imgdel';
        } else if($(element).attr('class').indexOf('recCanceled') > 0) {
          var delTitle = "<?php _e('Exception activation','events-calendar');?>",
              icondel = "flash.png", classdel = 'activexcept';
        } else if(!event.isexcept){
          var delTitle = "<?php _e('Recurrence canceling','events-calendar');?>",
              icondel = "disable.gif", classdel = 'reccancel';
        }
      } else {
        var delTitle = "<?php _e('Event delete','events-calendar');?>",
            icondel = "trash.png", classdel = 'imgdel';
      }
    	var imgdel = $("<img src='"+imgPath+"/"+icondel+"' title='"+delTitle+"' class='"+classdel+"'/>")
        .prependTo($(element).find('td.w'));
    }

    function processExceptIcon(event, element) {
    	var imgexcept = $('<img id="imgexcept-'+event.id+'" src="'+imgPath+'/isexcept.png" title="<?php _e('This is an exception','events-calendar');?>"/>')
        .css({position:'absolute',top:($(element).position().top),left:($(element).position().left + $(element).width() - 14)})
        .click(function(){
          var user_can_update = (can_update || (can_owner_update && event.owner === user_login));
          if(user_can_update)
            event.url += '&EC_except=true';
        })
        .prependTo($(element).find('td.w'));
    }

  	$('#calendar').fullCalendar({
  	  year: <?php echo $year?>,
  	  month: <?php echo $month - 1?>,
  	  //rightToLeft:false,
  		draggable: true,
  		fixedWeeks: <?php echo $fixedWeeks;?>,
  		abbrevDayHeadings: false,
  		showTime: <?php echo $showtime;?>,
  		timeFormat: "<?php echo $tttf;?>",
  		weekStart: <?php echo WPECFDW;?>,
  		weekendDays: [<?php echo implode(",",$nb_we);?>],
  		startParam: 'EC_start',
  		endParam: 'EC_end',
  		actionParam: 'EC_action',
  		action: 'ajaxGetMonthEvents',
  		events: "admin.php?page=events-calendar-manage",
      loading: function(bool) {
				if (bool) $('#loading').show();else $('#loading').hide();
		  },
		  monthDisplay: function(){
        $(weekends).css('background-color','#f0ffff');
      },
      eventRender: function(event, element) {
        var user_can_update = (can_update || (can_owner_update && event.owner === user_login));
        $(element).css('cursor',(user_can_update ? 'pointer':'default'));
        if(user_can_update) processIconsEvent(event, element);
        var conditionEventTypes = (enableEventTypes && in_array(event.type, eventIdTypes) && event.type > 'evt1');
        var conditionRecurrence = (enableRec && event.rec > 0 && recColors[event.rec] != '' && $(element).attr('class').indexOf('recStart') < 0 && $(element).attr('class').indexOf('recEnd') < 0 );
        if(enableEventTypes) {
          if(enableRec) {
            if(typePriority) {
              if(conditionEventTypes) processBgEvent(element,(arrayTypes[event.type][1]+''));
              if(conditionRecurrence) processTypeWitness(element,(recLabel[event.rec]+''),(recColors[event.rec]+''));
            } else {
              if(conditionEventTypes) processTypeWitness(element,(arrayTypes[event.type][0]+''),(arrayTypes[event.type][1]+''));
              if(conditionRecurrence) processBgEvent(element,(recColors[event.rec]+''));
            }
          } else if(conditionEventTypes && $(element).attr('class').indexOf('recStart') < 0 && $(element).attr('class').indexOf('recEnd') < 0) processBgEvent(element,(arrayTypes[event.type][1]+''));
        } else if(conditionRecurrence) processBgEvent(element,(recColors[event.rec]+''));
        // Attach the tooltip to the event
				if(typeof event.innertooltip != 'undefined')
				  $(element).find('.event-title')
            .attr('title',event.innertooltip)
            .tooltip({delay:0,track:true});
      },
      afterRender: function(event, element) {
        $(element).css({width:($(element).width()-2),left:($(element).position().left+2)});
        if(event.rec > 0 && event.isexcept) processExceptIcon(event, element);
      },
		  eventClick: function(event,jsEvent) {
		    var imgTarget = jsEvent.target;
		    var element = this;
		    switch (imgTarget.className) {
	       case 'imgdel':
           jConfirm(delConfMsg+event.title, delConfTitle, function(doDelete){
              if(doDelete) {
                $.get("<?php bloginfo('wpurl');?>/wp-admin/admin.php?page=events-calendar-main",
                  {EC_action: "ajaxDelete", EC_id: event.idb},
                  function(data) {
                    $.each($('table.idb-'+event.idb),function() {
                      $('table.idb-'+event.idb+' td').css('background', 'red');
                      $(this).fadeOut(1000);
                    });
                  });
              }
           });
           return false;
         case 'activexcept': // Re activate a previously canceled recurrence 
           jConfirm(excConfMsg, excConfTitle, function(doActivate){
              if(doActivate) {
                var sendStart = $.fullCalendar.formatDate(event.start, 'Y-m-d');
                $.get("<?php bloginfo('wpurl');?>/wp-admin/admin.php?page=events-calendar-main",
                  {EC_action: "ajaxActivExcept", EC_id: event.idb, EC_start: sendStart},
                  function(data) {
                    event.className = 'idb-'+event.idb;
                    var reccur = element.className.substr(element.className.indexOf('rec-'),7);
                    $.each($('table.'+reccur+'.recCanceled.idb-'+event.idb),function() {
                      $(this).find('.activexcept').remove();
                      $(this).removeClass('recCanceled');
                      processIconsEvent(event, $(this));
                      event.isexcept = false;
                      event.revert = false;                      
                      $(this).find('#imgexcept-'+event.id).remove();
                      $(this).find('.typewitness').prependTo($(this).find('td.w'));
                    });
                });
              }
           });
           return false;
         case 'reccancel': // Cancel a recurrence
           jConfirm(canConfMsg, canConfTitle, function(doCancel){
              if(doCancel) {
                var sendStart = $.fullCalendar.formatDate(event.start, 'Y-m-d');
                $.get("<?php bloginfo('wpurl');?>/wp-admin/admin.php?page=events-calendar-main",
                  {EC_action: "ajaxCancelRec", EC_id: event.idb, EC_start: sendStart},
                  function(data) {
                    event.className = ['recCanceled', 'idb-'+event.idb];
                    var reccur = element.className.substr(element.className.indexOf('rec-'),7);
                    $.each($('table.'+reccur+'.idb-'+event.idb),function() {
                      $(this).find('.reccancel').remove();
                      $(this).addClass('recCanceled');
                      processIconsEvent(event, $(this));
                      event.isexcept = true;
                      event.revert = true;
                      processExceptIcon(event, $(this));
                      $(this).find('.typewitness').prependTo($(this).find('td.w'));
                    });
                });
              }
           });
           return false;
         default: return true;
        }
		  },
		  eventDragStart: function(event, jsEvent, ui) {
		    if(event.rec > 0 && event.isexcept) $("#imgexcept-"+event.id).hide();
      },
      eventDrop:function(event, delta, jsEvent, ui) {
        if(event.revert === true) return;
        var sendNew = $.fullCalendar.formatDate(event.start, 'Y-m-d');
        var oldDate = new Date(+event.start)
        oldDate.setDate(oldDate.getDate() - delta );
        var sendStart = $.fullCalendar.formatDate(oldDate, 'Y-m-d');
        //alert(sendStart+','+sendNew); return;
        if(event.rec > 0) {
            event.isexcept = (sendNew !== event.orgrec);
            sendOrgRec = event.orgrec ? event.orgrec : 'false';
            event.orgrec = !event.orgrec ? sendStart : event.orgrec;
          $.get("<?php bloginfo('wpurl');?>/wp-admin/admin.php?page=events-calendar-main",
            {EC_action: "ajaxMoveRec", EC_id: event.idb, EC_start: sendStart, EC_new: sendNew, EC_org: sendOrgRec},
            function(){});
        } else {
          $.get("<?php bloginfo('wpurl');?>/wp-admin/admin.php?page=events-calendar-main",
            {EC_action: "ajaxMoveEvent", EC_id: event.idb, EC_new: sendNew},
            function(data){});
        }
      },
      eventDragStop:function(event, jsEvent, ui) {
		    if(event.rec > 0 && event.isexcept) $("#imgexcept-"+event.id).show();
		    $('#tooltip').hide();
      }
    });
   });
})(jQuery);
</script>

<div id="calendar" style="margin:0 20px;position:relative;">
<div id="loading" style="display:block;"></div>
</div>
<?php
    if($enableTypes && $eventTypes[1] != '') {
      echo '<table width="97%" style="margin:1em 0 0 1.5em;"><tr><th ROWSPAN=100 align=left valign=top width="15%">'._c('Types &amp; colors:','events-calendar').'</th><td width="12.5%" align=center style="background-color:'.$colorTypes[1].';color:'.contrastColor($colorTypes[1]).';" >'.$eventTypes[1].'</td>';
        for($i=2;$i<count($this->typesList);$i++) {
          echo '<td width="12%" align=center style="background-color:'.$colorTypes[$i].';color:'.contrastColor($colorTypes[$i]).';" >'.$eventTypes[$i].'</td>';
          if($i%7 == 0) echo '</tr><tr>';
        }
      echo '</tr></table>';
    }
    if($enableRec && $recLabel[1] != '') {
      echo '<table width="97%" style="margin:1em 0 0 1.5em;"><tr><th ROWSPAN=100 align=left valign=top width="14%">'._c('Recurrences &amp; colors:','events-calendar').'</th><td width="12.5%" align=center style="background-color:'.$recColors[1].';color:'.contrastColor($recColors[1]).';" >'.$recLabel[1].'</td>';
        for($i=2;$i<9;$i++) {
          if($i == 5) continue;
          echo '<td width="20%" align=center style="background-color:'.$recColors[$i].';color:'.contrastColor($recColors[$i]).';" >'.$recLabel[$i].'</td>';
          if($i%4 == 0) echo '</tr><tr>';
        }
      echo '</tr></table>';
    }
  }

    /**
     * Display Tooltip in EC Management.
     *
     * @param int $month          month to display
     * @ra,m int $year          year to display
     *
     * @global string         Weeekday
     * @access private
     */
  function calendarData($year, $month) {
    $db = new EC_DB();
    global $ec_MonthNames, $ec_WeekdayString;
    // Capabilities
    $user_login = $this->user_login;
    $can_update = $this->user_rights[2];
    $can_owner_update = $this->user_rights[4];
    wpec_get_option($this,'wpecOptionsGenSet');
    // Option : date & time format
    $ttdf = explode('=',$this->ecopt_ttdf); $ttdf = $ttdf[1];
    $tttf = explode('=',$this->ecopt_tttf); $tttf = $tttf[1];
    // jSon Array
    $ajaxEvent = array();
    // Auto incremental jSON id
    $id=0;
    // Get list of colors Events Type
    wpec_get_option($this,'wpecOptionsEv');
    if(isset($this->ecopt_ev_types)) {
      $enableEventTypes = true;
      wpec_get_option($this,'wpecOptionsTypes');
      $this->typesList = mb_unserialize(stripslashes($this->ecopt_sertypes));
      $colorTypesFlag = ($this->typesList != false);
      if($colorTypesFlag) {
        $colorTypes = array();
        $eventTypes = array();
        $c = count($this->typesList);
        for($i=1;$i<$c;$i++) {
          $colorTypes[$this->typesList[$i]['tid']] = $this->typesList[$i]['col'];
          $eventTypes[$this->typesList[$i]['tid']] = $this->typesList[$i]['des'];
          $levelTypes[$this->typesList[$i]['tid']] = $this->typesList[$i]['rig'];          
        }
      } else {
        $enableEventTypes = false;
        $colorTypes = $eventTypes = array();
      }
    } else {
      $enableEventTypes = false;
      $colorTypes = $eventTypes = array();
    }
    if(strlen($year)>4) {  // If the call came from fullcalendar year = start and month = end range
      $startRange = $year; $startTS = strtotime($startRange);
      $endRange = $month; $endTS = strtotime($endRange);
      list($year,$month,$day) = explode('-',$year);
      if($day>1) $month++;
    } else {
      $month = $month ? $month : date('m');
      $year  = $year  ? $year  : date('Y');
      $startTS = mktime(0,0,0,$month,1,$year);
      $startRange = date('Y-m-d', strtotime('-'.((strftime('%w',$startTS) - WPECFDW + 7) % 7).' days',$startTS));
      if($this->fixedWeeks == 'true')  // 6 weeks = 42 days each month
        $endRange = date('Y-m-d', strtotime('+ 41 days',strtotime($startRange)));
      else {
        $lastDay = mktime(0, 0, 0, ($month+1), 0, $year);
        $endRange = date('Y-m-d', strtotime('+ 1 month '.((7 - strftime('%w',$lastDay) + WPECFDW) % 7 - 1).' days',strtotime($startRange)));
      }
      $endTS = strtotime($endRange);
    }
    $nbDaysInMonth = round(((strtotime($endRange) - strtotime($startRange))/86400)+1);
    //echo $startRange,'<br/>',$endRange,'<br/>',$nbDaysInMonth;
    //die;
    $eventsOfMonth = $db->getMonthEvents($startRange, $endRange);
    $debug = false;
    foreach($eventsOfMonth as $e) :
      // check event accessibility
      $accessLevel = $e->accessLevel;       
      if($accessLevel !== 'public' && !current_user_can($accessLevel)) continue;
      // check type rights validity
      $type = $e->eventType;      
      if($type > 'evt1' && $levelTypes[$type] !== 'public' && !current_user_can($levelTypes[$type])) continue;
      
      $idb = $e->id;      
      $title = stripslashes($e->eventTitle);      
      $description = isset($e->eventDescription) ? stripslashes(strip_tags($e->eventDescription)) : '';
      $location = isset($e->eventLocation) ? stripslashes($e->eventLocation) : '';
      $linkout = isset($e->eventLinkout) ? $e->eventLinkout : '';
      $recStatus = isset($e->eventRecStatus) ? $e->eventRecStatus : false;
      $recProces = isset($e->eventRecProces) ? $e->eventRecProces : false;
      $recExcept = isset($e->eventExceptions) ? $e->eventExceptions : false;
      $owner = isset($e->eventCreator) ? $e->eventCreator : false;
      $user_can_update = ($can_update || ($can_owner_update && $owner == $user_login));
      $recStatusFlag = $recStatus ;
      $startDate = $e->eventStartDate;
      $endDate = $e->eventEndDate;
      $startTime = isset($e->eventStartTime) ? $e->eventStartTime : false;
      $endTime = isset($e->eventEndTime) ? $e->eventEndTime : false;
      $PostID = $e->postID;
      if ($recStatus && $recProces) {
        for($day = 0; $day <= $nbDaysInMonth; $day++) {
          $sqldate = date('Y-m-d', strtotime('+'.$day.' days',$startTS));
          //echo $sqldate,'<br/>',$e->id,'<br/>',$recStatus,'<br/>',$recProces,'<br/>',$recExcept,'<hr>';
          if(!processRecurrence($this, $sqldate, $startDate, $endDate, $recStatus, $recProces, $recExcept)) continue;
          $className = ''; $duration = $this->duration + 1;
          $output = '<p style=\'text-align:center;font-weight:bold;background-color:black;color:white;\'>';
          if($this->recIsCan) {
            $output .= _c('Reccur. Event: CANCELED','events-calendar');
            $className = 'recCanceled';
          } elseif($this->recIsStart) {
            $output .= _c('Reccur. Event: Start','events-calendar');
            if($this->recIsExcept) $output .= '<br/><b>'._c('EXCEPTION','events-calendar').'</b><br/>';
            $className = 'recStart';
          } elseif($this->recIsEnd) {
            $output .= _c('Reccur. Event: End','events-calendar');
            if($this->recIsExcept) $output .= '<br/><b>'._c('EXCEPTION','events-calendar').'</b><br/>';
            $className = 'recEnd';
          } else {
            $output .= _c('Reccur. Event','events-calendar');
            if($this->recIsExcept) $output .= '<br/><b>'._c('EXCEPTION','events-calendar').'</b><br/>';
          }
          $output .= '</p>';

          $output .= "<b>Id: </b>$idb<br/>";
          $output .= '<b>'._c('Title','events-calendar').": </b>$title<br/>";
          if($type > 'evt1') {
            $output .= '<p style="color:'.contrastColor($colorTypes[$type]).';background:'.$colorTypes[$type].';padding:5px 2px;margin:0;"><b>'._c('Type','events-calendar').': </b>'.$eventTypes[$type].'</p>';
            $output .= '<b>'._c('Type rights','events-calendar').': </b>'.ec_convAccessLevel($levelTypes[$type]).'<br/>';            
          }
          if($location) $output .= '<b>'._c('Location','events-calendar').": </b>$location<br/>";
          if($description) $output .= "<b>"._c('Description','events-calendar').": </b>$description<br/>";
          if($owner) $output .= "<b>"._c('Owner','events-calendar').": </b>$owner<br/>";

          $output .= '<b>'._c('Recurrence','events-calendar').': </b>';
          switch ($recStatus) {
            case 1:
              $output .= sprintf(__('Every %s / month','events-calendar'),$this->recday).'<br/>';
              $output .= '<b>'._c('Duration','events-calendar').": </b>".($duration > 1 ? sprintf(__('%s days','events-calendar'),$duration):__('One day','events-calendar'));
              break;
            case 2:
              $output .= sprintf(__('Every %s days','events-calendar'),$this->recXday).'<br/>';
              $output .= '<b>'._c('Duration','events-calendar').': </b>'.($duration > 1 ? sprintf(__('%s days','events-calendar'),$duration):__('One day','events-calendar'));
              break;
            case 3:
              $weekdays = '';
              foreach ($this->weekdays as $value) $weekdays .= substr($ec_WeekdayString, $value, 1)." ";
              $output .= sprintf(__('Every %s','events-calendar'),$weekdays);
              break;
            case 4:
              $weeks = '';
              foreach ($this->weeks as $value) {
                if ($value == '4') $weeks .= _c('last','events-calendar');
                else $weeks .= '#'.($value+1).' ';
              }
              $output .= sprintf(__('Every %s week','events-calendar'),$weeks);
              break;
            case 6:
              $weeks = '';
              foreach ($this->weeks as $value) {
               if ($value == '4') $weeks .= _c('last','events-calendar');
               else $weeks .= '#'.($value+1).' ';
              }
              $output .= sprintf(__('Every %s days, %s week','events-calendar'),$this->recXday,$weeks);
              break;
            case 7:
              $weekdays = '';
              foreach ($this->weekdays as $value) $weekdays .= substr($ec_WeekdayString, $value, 1)." ";
              $weeks = '';
              foreach ($this->weeks as $value) {
               if ($value == '4') $weeks .= _c('last','events-calendar'); else $weeks .= "#".($value+1)." ";
              }
              $output .= sprintf(__('Every %s, %s week','events-calendar'),$weekdays,$weeks);
              break;
            case 8:
              $output .= __('Annual','events-calendar');
              break;
            default: break;
          }

          $recStartTime = $this->startTime ? $this->startTime : ($startTime ? $startTime : '00:00');
          $recEndTime = $this->endTime ? $this->endTime : ($endTime ? $endTime: '00:00');
          $recStartDate = strtotime($this->sqldate.'T'.$recStartTime);
          $recEndDate = strtotime(date('Y-m-d',strtotime('+ '.$this->duration.' days',strtotime($this->sqldate))).'T'.$recEndTime);
          $disStartDate = ($this->recIsStart || $this->recIsEnd) ? strtotime($startDate.'T'.($startTime ? $startTime : '00:00')) : $recStartDate;
          $disEndDate = ($this->recIsStart || $this->recIsEnd) ? strtotime($endDate.'T'.($endTime ? $endTime : '00:00')) : $recEndDate;
          $recOneDay = ($duration == 1);
          $oneDay = ($startDate == $endDate);
          $output .= '<br/><b>'.($oneDay ? _c('Date','events-calendar') : _c('Start Date','events-calendar')).': </b>'.wpec_date_i18n($ttdf, strtotime($startDate)).'<br/>';
          if(!$oneDay) $output .= '<b>'._c('End Date','events-calendar').': </b>'.wpec_date_i18n($ttdf, strtotime($endDate)).'<br/>';
          $output .= '<b>'.($recOneDay ? _c('Rec. date','events-calendar') : _c('Rec. Start date','events-calendar')).': </b>'.wpec_date_i18n($ttdf, $disStartDate).'<br/>';
          if(!$recOneDay) $output .= '<b>'._c('Rec. End date','events-calendar').': </b>'.wpec_date_i18n($ttdf, $disEndDate).'<br/>';
          if($this->orgRecDate) $output .= '<b>'._c('Original Rec.','events-calendar').': </b>'.wpec_date_i18n($ttdf, strtotime($this->orgRecDate)).'<br/>';
          if($startTime) $output .= '<b>'._c('Start Time','events-calendar').': </b>'.date($tttf, $disStartDate).'<br/>';
          if($endTime) $output .= '<b>'._c('End Time','events-calendar').': </b>'.date($tttf, $disEndDate).'<br/>';
          $output .= '<b>'._c('Visibility','events-calendar').": </b>".ec_convAccessLevel($accessLevel).'<br/>';

          if ($linkout) $output .= '<b>'._c('Link out','events-calendar')."</b> :".shorten_url($linkout, 22).'<br/>';
          if ($PostID) {
            $IDtmp = get_post($PostID);
            $ptitle = $IDtmp->post_title;
            $output .= '<b>'._c('Post','events-calendar')." ($PostID)</b> :".stripslashes($ptitle).'<br/>';
          }

          $ajaxEvent[] = array(
            'id'        => $id++,
            'idb'       => $idb,
            'url'       => $user_can_update ? ('?page=events-calendar-main&EC_action=edit&EC_id='.$idb.'&EC_month='.$month.'&EC_year='.$year):'',
            'title'     => $title,
            'type'      => $type,
            'owner'     => $owner,
            'access'    => $accessLevel,
            'start'     => date('c', $recStartDate),
            'end'       => date('c', $recEndDate),
            'rec'       => $recStatus,
            'isexcept'  => $this->recIsExcept,
            'orgrec'    => $this->orgRecDate,
            'draggable' => $user_can_update ? true:false,
            'revert'    => ($this->recIsStart || $this->recIsEnd || $this->recIsCan) ? true : false,
            'className' => array($className,'idb-'.$idb, 'rec-'. str_pad($day, 3, "0", STR_PAD_LEFT)),
            'innertooltip'  => $debug ? '' : $output
          );
        }
        continue;
      }
      $output = '';
      $output .= "<b>Id: </b>$idb<br/>";
      $output .= "<b>"._c('Title','events-calendar').": </b>$title<br/>";
      if($type > 'evt1') {
        $output .= '<p style="color:'.contrastColor($colorTypes[$type]).';background:'.$colorTypes[$type].';padding:5px 2px;margin:0;"><b>'._c('Type','events-calendar').': </b>'.$eventTypes[$type].'</p>';
        $output .= '<b>'._c('Type rights','events-calendar').': </b>'.ec_convAccessLevel($levelTypes[$type]).'<br/>';
      }        
      if($location) $output .= '<b>'._c('Location','events-calendar').": </b>$location<br/>";
      if($description) $output .= "<b>"._c('Description','events-calendar').": </b>$description<br/>";
      if($owner) $output .= "<b>"._c('Owner','events-calendar').": </b>$owner<br/>";

      $startMT = strtotime($startDate.'T'.$startTime);
      $endMT = strtotime($endDate.'T'.$endTime);

      $oneDay = ($startDate == $endDate);
      $output .= '<b>'.($oneDay ? _c('Date','events-calendar') : _c('Start Date','events-calendar')).': </b>'.wpec_date_i18n($ttdf, $startMT).'<br/>';
      if($startTime) $output .= '<b>'._c('Start Time','events-calendar').': </b>'.date($tttf, $startMT).'<br/>';
      if(!$oneDay) $output .= '<b>'._c('End Date','events-calendar').': </b>'.wpec_date_i18n($ttdf, $endMT).'<br/>';  // wpec_date_i18n($ttdf, $endMT, false)
      if($endTime) $output .= '<b>'._c('End Time','events-calendar').': </b>'.date($tttf, $endMT).'<br/>';
      $output .= '<b>'._c('Visibility','events-calendar').": </b>".ec_convAccessLevel($accessLevel).'<br/>';

      if ($linkout) $output .= '<b>'._c('Link out','events-calendar')."</b> :".shorten_url($linkout, 22).'<br/>';
      if ($PostID) {
        $IDtmp = get_post($PostID);
        $ptitle = $IDtmp->post_title;
        $output .= '<b>'._c('Post','events-calendar')." ($PostID)</b> :".stripslashes($ptitle).'<br/>';
      }
      $ajaxEvent[] = array(
        'id'        => $id++,
        'idb'       => $idb,
        'url'       => $user_can_update ? ('?page=events-calendar-main&EC_action=edit&EC_id='.$idb.'&EC_month='.$month.'&EC_year='.$year):'',
        'title'     => $title,
        'type'      => $type,
        'owner'     => $owner,
        'access'    => $accessLevel,        
        'start'     => date('c', $startMT),
        'end'       => date('c', $endMT),
        'rec'       => 0,
        'draggable' => $user_can_update ? true:false,
        'className' => 'idb-'.$idb,
        'innertooltip'  => $debug ? '' : $output
      );
    endforeach;
      /*
      function sortJsonAray($a,$b) {
        if ($a.idb == $b.idb) return 0;
        return ($a.idb < $b.idb) ? 1 : -1;
      }
      usort($ajaxEvent, "sortJsonAray");
      */
      if($debug)echo jsonReadable(json_encode($ajaxEvent), true);
      else {
        if(phpversion()<5) echo array_to_json($ajaxEvent);
        else echo json_encode($ajaxEvent);
      }
  }
}
endif;
?>