<?php
/*
--------------------------------------------------------------------------
This file is part of the WP Events Calendar project.

For questions, help, comments, discussion, etc., please join our
forum at {@link http://www.wp-eventscalendar.com/forum}. You can
also go to Luke's ({@link http://www.lukehowelll.com}) and
Heirem's ({@link http://heirem.fr}) blogs.

WP Events Calendar is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.   See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
--------------------------------------------------------------------------
*/

/**
 * This file contains the WP Events Calendar Database class.
 *
 * Long description to be done.
 *
 * @package       WP-Events-Calendar
 * @subpackage    Core
 * @author
 *                - Luke Howell <luke@wp-eventscalendar.com>
 *                - Brad Gwathney <coe@wp-eventscalendar.com>
 *                - Ren MALKA <heirem@wp-eventscalendar.com>
 * @link
 *                - http://wp-eventscalendar.com/
 *                - http://www.lukehowell.com
 *                - http://myboxtool.com/
 *                - http://heirem.fr
 *                - http://laplix.com
 *                - http://www.gwathneydesign.com/
 * @since         6.0.0
 * @copyright
 *                - Copyright (c) 2007-2009 Luke Howell
 *                - Copyright (c) 2007-2009 Brad Bodine
 *                - Copyright (c) 2008-2009 Ren Malka
 *                - Copyright (c)      2009 Louis Lapointe
 *                - Copyright (c)      2009 Coe Gwathney
 * @license       GPLv3 {@link http://www.gnu.org/licenses/gpl}
 * @filesource
 *
 */
if(!class_exists('EC_DB')):

/**
 * This class is used by WPEC to access and modify the database.
 *
 * All the DB work needed by WPEC is done through this class.
 *
 * If installing the plugin, the class will be called upon to create
 * the WPEC database table.
 *
 * Later on, EC_DB will be used to create, modify and delete events.
 *
 * @package       WP-Events-Calendar
 * @subpackage    Core
 * @since         {@internal not documented yet}
 */
class EC_DB {

   /**
    * Holds the global $wpdb WP variable
    * @var object
    */
   var $db;

   /**
    * Holds the name of the WPEC table where events are going to be
    * maintained.
    * @var string
    */
   var $mainTable;

   /**
    * Holds the $maintable version
    * @var int
    */
  var $dbVersion;

   /**
    * Constructor.
    *
    * Sets up the class with $wpdb, $maintable and so nn.
    */
  function EC_DB() {
    global $wpdb;
    $this->dbVersion = "110";
    $this->db = $wpdb;
    $this->mainTable = $this->db->prefix . 'eventscalendar_main';
    $this->mainTableCaps = $this->db->prefix . 'EventsCalendar_main';
    $this->postsTable = $this->db->prefix . 'posts';
    if($this->db->get_var("show tables like '$this->mainTableCaps'") == $this->mainTableCaps )
      $this->mainTable = $this->mainTableCaps;
  }

  /**
   * Creates the WPEC table.
   *
   * Also take care if upgrading it if the table already exists and the DB version
   * is not the same as the current one.
   */
  function createTable() {
    if($this->db->get_var("show tables like '$this->mainTable'") != $this->mainTable ) {
      $sql = "CREATE TABLE " . $this->mainTable . " (
            id mediumint(9) NOT NULL AUTO_INCREMENT,
            eventTitle varchar(255) CHARACTER SET utf8 NOT NULL,
            eventType varchar(255) CHARACTER SET utf8 NOT NULL default 'evt0',
            eventDescription text CHARACTER SET utf8 DEFAULT NULL,
            eventLocation varchar(255) CHARACTER SET utf8 default NULL,
            eventLinkout varchar(255) CHARACTER SET utf8 default NULL,
            eventStartDate date NOT NULL,
            eventStartTime time DEFAULT NULL,
            eventEndDate date NOT NULL,
            eventEndTime time DEFAULT NULL,
            eventTdevt boolean DEFAULT FALSE,
            eventRecStatus mediumint(1) NULL DEFAULT NULL,
            eventRecProces varchar(255) CHARACTER SET utf8 default NULL,
            accessLevel varchar(255) CHARACTER SET utf8 NOT NULL default 'public',
            postID mediumint(9) NULL DEFAULT NULL,
            eventPhase varchar(255) CHARACTER SET utf8 NOT NULL default 'planning',
            eventParticipation varchar(255) CHARACTER SET utf8 NOT NULL default 'public',
            eventAdress varchar(255) CHARACTER SET utf8 DEFAULT NULL,
            eventGglml text CHARACTER SET utf8 DEFAULT NULL,
            eventContacts text CHARACTER SET utf8 DEFAULT NULL,
            eventCosts varchar(255) CHARACTER SET utf8 DEFAULT NULL,
            eventCustfields text CHARACTER SET utf8 DEFAULT NULL,
            eventAdminotes text CHARACTER SET utf8 DEFAULT NULL,
            eventExceptions text CHARACTER SET utf8 DEFAULT NULL,
            eventCreator varchar(255) CHARACTER SET utf8 NOT NULL,
            PRIMARY KEY  id (id)
            );";
      require_once(ABSPATH . "wp-admin/includes/upgrade.php");
      dbDelta($sql);
      // Request whithout CHARACTER SET utf8 if the CREATE TABLE failed
      if($this->db->get_var("show tables like '$this->mainTable'") != $this->mainTable ) {
        $sql = str_replace("CHARACTER SET utf8 ","",$sql);
        dbDelta($sql);
      }
      add_option("events_calendar_db_version", $this->dbVersion);
    }

    $installed_ver = get_option( "eventscalendar_db_version" );

    if($installed_ver != $this->dbVersion) {
      $sql = "CREATE TABLE " . $this->mainTable . " (
            id mediumint(9) NOT NULL AUTO_INCREMENT,
            eventTitle varchar(255) CHARACTER SET utf8 NOT NULL,
            eventType varchar(255) CHARACTER SET utf8 NOT NULL default 'evt0',
            eventDescription text CHARACTER SET utf8 DEFAULT NULL,
            eventLocation varchar(255) CHARACTER SET utf8 default NULL,
            eventLinkout varchar(255) CHARACTER SET utf8 default NULL,
            eventStartDate date NOT NULL,
            eventStartTime time DEFAULT NULL,
            eventEndDate date NOT NULL,
            eventEndTime time DEFAULT NULL,
            eventTdevt boolean DEFAULT FALSE,
            eventRecStatus mediumint(1) NULL DEFAULT NULL,
            eventRecProces varchar(255) CHARACTER SET utf8 default NULL,
            accessLevel varchar(255) CHARACTER SET utf8 NOT NULL default 'public',
            postID mediumint(9) NULL DEFAULT NULL,
            eventPhase varchar(255) CHARACTER SET utf8 NOT NULL default 'planning',
            eventParticipation varchar(255) CHARACTER SET utf8 NOT NULL default 'public',
            eventAdress varchar(255) CHARACTER SET utf8 DEFAULT NULL,
            eventGglml text CHARACTER SET utf8 DEFAULT NULL,
            eventContacts text CHARACTER SET utf8 DEFAULT NULL,
            eventCosts varchar(255) CHARACTER SET utf8 DEFAULT NULL,
            eventCustfields text CHARACTER SET utf8 DEFAULT NULL,
            eventAdminotes text CHARACTER SET utf8 DEFAULT NULL,
            eventExceptions text CHARACTER SET utf8 DEFAULT NULL,
            eventCreator varchar(255) CHARACTER SET utf8 NOT NULL,
            PRIMARY KEY  id (id)
            );";
      require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
      if (!dbDelta($sql)) {
        $sql = str_replace("CHARACTER SET utf8 ","",$sql);
        dbDelta($sql);
      }
      $this->db->query("UPDATE " . $this->mainTable . " SET `eventLocation` = REPLACE(`eventLocation`,' ','') WHERE `eventLocation` = ' ';"); // Thanx to James ;)
      $this->db->query("UPDATE " . $this->mainTable . " SET `eventLocation` = REPLACE(`eventLocation`,'',NULL) WHERE `eventLocation` = '';");
      $this->db->query("UPDATE " . $this->mainTable . " SET `eventStartTime` = REPLACE(`eventStartTime`,'00:00:00',NULL);");
      $this->db->query("UPDATE " . $this->mainTable . " SET `eventEndTime` = REPLACE(`eventEndTime`,'00:00:00',NULL);");
      $this->db->query("UPDATE " . $this->mainTable . " SET `eventCreator` = 'admin';");
      update_option( "events_calendar_db_version", $this->dbVersion);
    }
  }

  /**
   * WPEC comes with many options. This method initializes them.
   * By calling the internal wpec_get_option function , the defaults options are automatically created.
   * Only the options necessary for activation are created. The others will be so necessary during the use of the plugin
   */
  function initOptions() {
    wpec_get_option($this, 'wpecOptionsGenSet'); // general settings
    wpec_get_option($this, 'wpecOptionsRights'); // Rights according to roles
    wpec_get_option($this, 'wpecOptionsJtts');   // jQuery Tooltips settings by default
    wpec_get_option($this, 'wpecOptionsJtbs');   // jQuery Tickbox  settings by default
    wpec_get_option($this, 'wpecOptionsLc');     // Large calendar settings
    wpec_get_option($this, 'wpecOptionsEv');     // Events settings
    wpec_get_option($this, 'wpecOptionsTypes');  // Types of events settings

    // Old options for temporary compatibility
    $options = get_option('optionsEventsCalendar');
    if(!is_array($options)) $options = array();
    if (!isset($options['dateFormatWidget'])) $options['dateFormatWidget'] = 'm-d';
    if (!isset($options['timeFormatWidget'])) $options['timeFormatWidget'] = 'g:i a';
    if (!isset($options['dateFormatLarge'])) $options['dateFormatLarge'] = 'n/j/Y';
    if (!isset($options['timeFormatLarge'])) $options['timeFormatLarge'] = 'g:i a';
    if (!isset($options['timeStep'])) $options['timeStep'] = '30';
    if (!isset($options['adaptedCSS'])) $options['adaptedCSS'] = '';
    if (!isset($options['jqueryextremstatus'])) $options['jqueryextremstatus'] = 'false';
    if (!isset($options['todayCSS'])) $options['todayCSS'] = 'border:thin solid blue;font-weight: bold;';
    if (!isset($options['dayHasEventCSS'])) $options['dayHasEventCSS'] = 'color:red;';
    if (!isset($options['daynamelength'])) $options['daynamelength'] = '3';
    if (!isset($options['daynamelengthLarge'])) $options['daynamelengthLarge'] = '3';
    if (!isset($options['accessLevel'])) $options['accessLevel'] = 'level_10';
    update_option('optionsEventsCalendar', $options);
  }
  /**
   * Adds an event.
   *
   * @param string   $title               Title of the event.
   * @param mixed    $type                What kind of event is this? Fund raiser, Dinner party?
   * @param string   $description         Description of the event.
   * @param date     $startDate           Starting date of the event.
   * @param date     $endDate             Ending date of the event.
   * @param time     $startTime           Starting time of the event.
   * @param time     $endTime             Ending time of the event.
   * @param string   $location            Location of the event
   * @param string   $linkout             URL to the corresponding web site
   * @param mixed    $phase
   * @param mixed    $participation
   * @param mixed    $accessLevel         Access level
   * @param mixed    $postID              the post id
   * @param mixed    $ec_adress           address ??
   * @param mixed    $googlemaplink       a googlemap link to location
   * @param mixed    $ec_contacts
   * @param mixed    $ec_costs
   * @param mixed    $ec_cfields
   * @param mixed    $adminotes
   * @param mixed    $recurrStatus
   * @param mixed    $recurrProces
   * @param mixed    $excptArr
   * @param mixed    $tdevt
   */
  function addEvent($title, $type, $description, $startDate, $endDate, $startTime, $endTime, $location, $linkout, $phase, $participation, $accessLevel, $postID, $ec_adress, $googlemaplink, $ec_contacts, $ec_costs, $ec_cfields, $adminotes, $recurrStatus, $recurrProces, $excptArr, $tdevt, $creator) {
    $postID = is_null($postID) ? "NULL" : "'$postID'";
    $location = is_null($location) ? "NULL" : "'$location'";
    $description = is_null($description) ? "NULL" : "'$description'";
    $startDate = is_null($startDate) ? "NULL" : "'$startDate'";
    $endDate = is_null($endDate) ? "NULL" : "'$endDate'";
    $linkout = is_null($linkout) ? "NULL" : "'$linkout'";
    $startTime = is_null($startTime) ? "NULL" : "'$startTime'";
    $accessLevel = is_null($accessLevel) ? "NULL" : "'$accessLevel'";
    $endTime = is_null($endTime) ? "NULL" : "'$endTime'";
    $recurrStatus = is_null($recurrStatus) ? "NULL" : "'$recurrStatus'";
    $recurrProces = is_null($recurrProces) ? "NULL" : "'$recurrProces'";
    $type = is_null($type) ? "NULL" : "'$type'";
    $phase = is_null($phase) ? "'planning'" : "'$phase'";
    $participation = is_null($participation) ? "'public'" : "'$participation'";
    $ec_adress = is_null($ec_adress) ? "NULL" : "'$ec_adress'";
    $googlemaplink = is_null($googlemaplink) ? "NULL" : "'$googlemaplink'";
    $ec_contacts = is_null($ec_contacts) ? "NULL" : "'$ec_contacts'";
    $ec_costs = is_null($ec_costs) ? "NULL" : "'$ec_costs'";
    $ec_cfields = is_null($ec_cfields) ? "NULL" : "'$ec_cfields'";
    $adminotes = is_null($adminotes) ? "NULL" : "'$adminotes'";
    $excptArr = is_null($excptArr) ? "NULL" : "'$excptArr'";
    $tdevt = (!$tdevt) ? "FALSE" : "TRUE";
    $creator = (!$creator) ? "admin" : "'$creator'";

    $sql = "INSERT INTO `$this->mainTable` ("
          ."`id`, `eventTitle`, `eventType`, `eventDescription`, `eventLocation`, `eventLinkout`,`eventStartDate`, `eventStartTime`, `eventEndDate`, `eventEndTime`, `eventRecStatus`, `eventRecProces`,`accessLevel`, `postID`, `eventPhase`, `eventParticipation`, `eventAdress`, `eventGglml`, `eventContacts`, `eventCosts`, `eventCustfields`, `eventAdminotes`, `eventExceptions`, `eventTdevt`, `eventCreator`) "
          ."VALUES ("
          ."NULL , '$title', $type, $description, $location, $linkout, $startDate, $startTime, $endDate, $endTime, $recurrStatus, $recurrProces, $accessLevel, $postID, $phase, $participation, $ec_adress, $googlemaplink, $ec_contacts, $ec_costs, $ec_cfields, $adminotes, $excptArr, $tdevt, $creator);";
    $this->db->query($sql);
    //echo $sql;
  }

  /**
   * Updates an event.
   *
   * @param mixed   $id
   * @param mixed   $title
   * @param mixed   $type
   * @param mixed   $description
   * @param mixed   $startDate
   * @param mixed   $endDate
   * @param mixed   $startTime
   * @param mixed   $endTime
   * @param mixed   $location
   * @param mixed   $linkout
   * @param mixed   $phase
   * @param mixed   $participation
   * @param mixed   $accessLevel
   * @param mixed   $postID
   * @param mixed   $ec_adress
   * @param mixed   $googlemaplink
   * @param mixed   $ec_contacts
   * @param mixed   $ec_costs
   * @param mixed   $ec_cfields
   * @param mixed   $adminotes
   * @param mixed   $recurrStatus
   * @param mixed   $recurrProces
   * @param mixed   $excptArr
   * @param mixed   $tdevt
   */
  function editEvent($id, $title, $type, $description, $startDate, $endDate, $startTime,  $endTime, $location, $linkout, $phase, $participation, $accessLevel, $postID, $ec_adress, $googlemaplink, $ec_contacts, $ec_costs, $ec_cfields, $adminotes, $recurrStatus, $recurrProces, $excptArr, $tdevt) {
    $postID = is_null($postID) ? "NULL" : "'$postID'";
    $location = is_null($location) ? "NULL" : "'$location'";
    $description = is_null($description) ? "NULL" : "'$description'";
    $startDate = is_null($startDate) ? "NULL" : "'$startDate'";
    $endDate = is_null($endDate) ? "NULL" : "'$endDate'";
    $linkout = is_null($linkout) ? "NULL" : "'$linkout'";
    $startTime = is_null($startTime) ? "NULL" : "'$startTime'";
    $accessLevel = is_null($accessLevel) ? "NULL" : "'$accessLevel'";
    $endTime = is_null($endTime) ? "NULL" : "'$endTime'";
    $recurrStatus = is_null($recurrStatus) ? "NULL" : "'$recurrStatus'";
    $recurrProces = is_null($recurrProces) ? "NULL" : "'$recurrProces'";
    $type = is_null($type) ? "NULL" : "'$type'";
    $phase = is_null($phase) ? "NULL" : "'$phase'";
    $participation = is_null($participation) ? "NULL" : "'$participation'";
    $ec_adress = is_null($ec_adress) ? "NULL" : "'$ec_adress'";
    $googlemaplink = is_null($googlemaplink) ? "NULL" : "'$googlemaplink'";
    $ec_contacts = is_null($ec_contacts) ? "NULL" : "'$ec_contacts'";
    $ec_costs = is_null($ec_costs) ? "NULL" : "'$ec_costs'";
    $ec_cfields = is_null($ec_cfields) ? "NULL" : "'$ec_cfields'";
    $adminotes = is_null($adminotes) ? "NULL" : "'$adminotes'";
    $excptArr = is_null($excptArr) ? "NULL" : "'$excptArr'";
    $tdevt = (!$tdevt) ? "FALSE" : "TRUE";
    $sql = "UPDATE `$this->mainTable` SET "
          ."`eventTitle` = '$title', "
          ."`eventType` = $type, "
          ."`eventDescription` = $description, "
          ."`eventLocation` = $location, "
          ."`eventLinkout` = $linkout, "
          ."`eventStartDate` = $startDate, "
          ."`eventStartTime` = $startTime, "
          ."`eventEndDate` = $endDate, "
          ."`eventEndTime` = $endTime, "
          ."`eventRecStatus` = $recurrStatus, "
          ."`eventRecProces` = $recurrProces, "
          ."`postID` = $postID, "
          ."`eventPhase` = $phase, "
          ."`eventParticipation` = $participation, "
          ."`eventAdress` = $ec_adress, "
          ."`eventGglml` = $googlemaplink, "
          ."`eventContacts` = $ec_contacts, "
          ."`eventCosts` = $ec_costs, "
          ."`eventCustfields` = $ec_cfields, "
          ."`eventAdminotes` = $adminotes, "
          ."`eventExceptions` = $excptArr, "
          ."`eventTdevt` = $tdevt,"
          ."`accessLevel` = $accessLevel WHERE `id` = $id LIMIT 1;";
    $this->db->query($sql);
  }

  /**
   * Deletes an event identified by $id
   *
   * @param int $id       id of the event to delete
   */
  function deleteEvent($id) {
    $sql = "DELETE FROM `$this->mainTable` WHERE `id` = $id LIMIT 1;";
    $this->db->query($sql);
  }

  /**
   * Ajax Entry for admin calendar : Uncanceling an exception
   *
   * @param int $id       id of the event in db
   * @param string $start    date of the exception to uncancel
   */
  function activExcept($id, $start) {
    $sql = "SELECT eventExceptions FROM `$this->mainTable` WHERE `id` = $id LIMIT 1;";
    $result = $this->db->get_results($sql);
    foreach($result as $excpt) {
      foreach($excpt as $recExcept) {
        if(!empty($recExcept)) {
          $recUsExcept = mb_unserialize(html_entity_decode(stripslashes($recExcept)));
          for($i=0;$i<count($recUsExcept);$i++) {
            if($recUsExcept[$i]['hdt'] == $start) {
              array_splice($recUsExcept,$i,1);
              if(count($recUsExcept) > 0)
                $recExcept = $this->db->escape(htmlentities(serialize($recUsExcept),ENT_QUOTES));
              else $recExcept = '';
              $this->db->query("UPDATE `$this->mainTable` SET `eventExceptions` = '$recExcept' WHERE `id` = $id LIMIT 1;");
              return;
            }
          }
        }
      }
    }
  }

  /**
   * Ajax Entry for admin calendar : Canceling a recurrence
   *
   * @param int $id       id of the event in db
   * @param string $start    date of the recurrence to cancel
   */
  function cancelRec($id, $start) {
    $getRecc = array();
    $sql = "SELECT eventExceptions FROM `$this->mainTable` WHERE `id` = $id LIMIT 1;";
    $result = $this->db->get_results($sql);
    foreach($result as $excpt) {
      //if($_GET['EC_debug'] == 'yes') echo var_dump($excpt);
      foreach($excpt as $recExcept) {
        if(!empty($recExcept)) {
          $recUsExcept = mb_unserialize(html_entity_decode(stripslashes($recExcept)));
          for($i=0;$i<count($recUsExcept);$i++) {
            array_push($getRecc, $recUsExcept[$i]);
            if($recUsExcept[$i]['hdt'] == $start) {
              $recUsExcept[$i]['can'] = 'x';
              $recUsExcept[$i]['ndt'] = $recUsExcept[$i]['dur'] = $recUsExcept[$i]['nst'] = $recUsExcept[$i]['net'] = '';
              $recExcept = $this->db->escape(htmlentities(serialize($recUsExcept),ENT_QUOTES));
              $this->db->query("UPDATE `$this->mainTable` SET `eventExceptions` = '$recExcept' WHERE `id` = $id LIMIT 1;");
              return;
            }
          }
        }
      }
    }
    if(count($getRecc) > 0 ) {
      // Add a exception at the existing list
      $recUsExcept = array('hdt' => $start, 'can' => 'x', 'ndt' => '', 'dur' => '', 'nst' => '', 'net' => '');
      array_push($getRecc, $recUsExcept);
      //echo var_dump($getRecc); die;
      $recExcept = $this->db->escape(htmlentities(serialize($getRecc),ENT_QUOTES));
      $this->db->query("UPDATE `$this->mainTable` SET `eventExceptions` = '$recExcept' WHERE `id` = $id LIMIT 1;");
    } else {
      // if not exception for this event we create the array
      $recUsExcept = array(array('hdt' => $start, 'can' => 'x', 'ndt' => '', 'dur' => '', 'nst' => '', 'net' => ''));
      $recExcept = $this->db->escape(htmlentities(serialize($recUsExcept),ENT_QUOTES));
      $this->db->query("UPDATE `$this->mainTable` SET `eventExceptions` = '$recExcept' WHERE `id` = $id LIMIT 1;");
    }
  }
  /**
   * Ajax Entry for admin calendar : Move a recurrence
   *
   * @param int $id       id of the event in db
   * @param string $start    date of the recurrence
   * @param string $new     new date of the recurrence
   * @param string $org     original date of the recurrence
   */
  function moveRec($id, $start, $new, $org) {
    $getRecc = array();
    if($org != 'false') $start = $org;
    $sql = "SELECT eventExceptions FROM `$this->mainTable` WHERE `id` = $id LIMIT 1;";
    $result = $this->db->get_results($sql);
    foreach($result as $excpt) {
      //if($_GET['EC_debug'] == 'yes') echo var_dump($excpt);
      foreach($excpt as $recExcept) {
        if(!empty($recExcept)) {
          $recUsExcept = mb_unserialize(html_entity_decode(stripslashes($recExcept)));
          for($i=0;$i<count($recUsExcept);$i++) {
            array_push($getRecc, $recUsExcept[$i]);
            if($recUsExcept[$i]['hdt'] == $start) {
              if($start == $new) {
                if($recUsExcept[$i]['dur'] == '' && $recUsExcept[$i]['dur'] == '' && $recUsExcept[$i]['nst'] == '' && $recUsExcept[$i]['net'] == '')
                 array_splice($recUsExcept,$i,1);
                else $recUsExcept[$i]['ndt'] = '';
              }
              else $recUsExcept[$i]['ndt'] = $new;
              $recExcept = $this->db->escape(htmlentities(serialize($recUsExcept),ENT_QUOTES));
              $this->db->query("UPDATE `$this->mainTable` SET `eventExceptions` = '$recExcept' WHERE `id` = $id LIMIT 1;");
              return;
            }
          }
        }
      }
    }
    // if there is no exception to update we create it
    if(count($getRecc) > 0 ) {
      // Add a exception at the existing list
      $recUsExcept = array('hdt' => $start, 'can' => '', 'ndt' => $new, 'dur' => '', 'nst' => '', 'net' => '');
      array_push($getRecc, $recUsExcept);
      $recExcept = $this->db->escape(htmlentities(serialize($getRecc),ENT_QUOTES));
      $this->db->query("UPDATE `$this->mainTable` SET `eventExceptions` = '$recExcept' WHERE `id` = $id LIMIT 1;");
    } else {
      // if not exception for this event we create the array
      $recUsExcept = array(array('hdt' => $start, 'can' => '', 'ndt' => $new, 'dur' => '', 'nst' => '', 'net' => ''));
      $recExcept = $this->db->escape(htmlentities(serialize($recUsExcept),ENT_QUOTES));
      $this->db->query("UPDATE `$this->mainTable` SET `eventExceptions` = '$recExcept' WHERE `id` = $id LIMIT 1;");
    }
  }
  /**
   * Ajax Entry for admin calendar : Move an event
   *
   * @param int $id       id of the event in db
   * @param string $new     new start date of the event
   */
  function moveEvent($id, $new) {
    $sql = "SELECT eventStartDate, eventEndDate FROM `$this->mainTable` WHERE `id` = $id LIMIT 1;";
    $result = $this->db->get_results($sql);
    foreach($result as $e) {
      $startDate = $e->eventStartDate;
      $endDate = $e->eventEndDate;
      $delta = round((strtotime($endDate) - strtotime($startDate))/86400);
      $endDate = date('Y-m-d',strtotime('+'.$delta.' days', strtotime($new)));
      $this->db->query("UPDATE `$this->mainTable` SET `eventStartDate` = '$new', `eventEndDate` = '$endDate' WHERE `id` = $id LIMIT 1;");
    }
  }
  /**
   * Return events where start or and specified by a date.
   * Called exclusively by full calendar
   * @param date $d     Date of the event
   * @param bool $recc  Recurring event? TRUE/FALSE
   * @return Standart object (array)      The database return data
   */
  //function getFcEvents($startRange, $endRange, $recc = true) {
  function getFcEvents($d, $recc = true) {
    $sql = "SELECT * FROM `$this->mainTable` WHERE (eventStartDate <= '$d' AND eventEndDate >= '$d' ) " . (($recc==true) ? "" : "AND eventRecStatus IS NULL ") . "ORDER BY eventStartTime, eventEndTime;";
    //$sql = "SELECT * FROM `$this->mainTable` WHERE (eventStartDate <= '$endRange' AND eventEndDate >= '$startRange' )" . (($recc==true) ? "" : "AND eventRecStatus IS NULL ") . "ORDER BY eventStartTime, eventEndTime;";
    $res = $this->db->get_results($sql);
    //echo $sql,'<br>';
    //echo var_dump($res),'<hr><br>';
    return $res;
  }

  /**
   * Return the day events specicied by $d.
   *
   * @param date $d     Date of the event
   * @param bool $recc  Recurring event? TRUE/FALSE
   * @return mixed      The database return data
   * @todo Need to know what we return "exactly", array? resultset?
   */
  function getDaysEvents($d, $recc = true) {
    $sql = "SELECT * FROM `$this->mainTable` WHERE eventStartDate <= '$d' AND eventEndDate >= '$d' " . (($recc==true) ? "" : "AND eventRecStatus IS NULL ") . "ORDER BY eventStartTime, eventEndTime;";
    $res = $this->db->get_results($sql);
//    echo $sql,'<br>';
//    echo var_dump($res),'<hr><br>';
    return $res;
  }

  /**
   * Return the events specicied by $start & $end dates
   *
   * @param $year       The Year
   * @param $month      The Month
   * @return mixed      The database return data
   */
  function getMonthEvents($start, $end) {
    wpec_get_option($this,'wpecOptionsEv');
    $sql = "SELECT * FROM `$this->mainTable` WHERE (eventStartDate <= '$end' AND eventEndDate >= '$start') " . (!isset($this->ecopt_ev_recc) ? "AND eventRecStatus IS NULL " : "") . " ORDER BY eventStartDate, eventStartTime;";
    //echo $sql,'<br/>';
    //echo var_dump($this->db->get_results($sql));
    //die;
    return $this->db->get_results($sql);
  }

  /**
   * Returns a single event specified by $id.
   *
   * @param int $id   The ebent id.
   * @return mixed    The database result.
   */
  function getEvent($id) {
    $sql = "SELECT * FROM `$this->mainTable` WHERE `id` = $id LIMIT 1;";
    return $this->db->get_results($sql);
  }

  /**
   * Loads the upcoming events.
   *
   * @param int $num       Number of evnts to read.
   * @param int $d         The event date
   * @return mixed         The DB results.
   * @todo                 This looks a lot like getNextEvents(). Duplication?
   *                       We should streamline these.
   */
  function getUpcomingEvents($num, $d) {
    $sql = "SELECT * FROM `$this->mainTable` WHERE eventStartDate >= '$d' AND eventRecStatus IS NULL ORDER BY eventStartDate, eventStartTime LIMIT $num;";
    return $this->db->get_results($sql);
  }

  /**
   * Loads future events.
   *
   * Difference with getUpcomingEvents() is the third parameter.
   * If set to TRUE, recurring events will be loaded.
   *
   * @param date $d        The day event
   * @param int  $num      Number of events to show
   * @param bool $recc     Get recurring events?
   * @return mixed         Database results
   * @todo                 Duplicates getMextEvents()
   */
  function getListEvents($d, $num, $recc = false) {
    $sql = "SELECT * FROM `$this->mainTable` WHERE eventStartDate >= '$d' " . (($recc==true) ? "" : "AND eventRecStatus IS NULL ") . "ORDER BY eventStartDate LIMIT $num;";
    return $this->db->get_results($sql);
  }

  /**
   * Loads previous events.
   *
   * @param date     $d       The evnt date
   * @param int      $num     Number of events to display
   * @param srint    $op      Operator to use
   *                          - if empty, '<' is used, otherwise we do "<$op"
   * @param bool     $recc    If TRUE, will retun reccurring events.
   * @return array
   */
  function getPrevEvents($d, $num, $op = '', $recc = false) {
    $sql = "SELECT * FROM `$this->mainTable` WHERE eventStartDate <$op '$d' " . (($recc==true) ? "" : "AND eventRecStatus IS NULL ") . "ORDER BY eventStartDate DESC LIMIT $num;";
    $result = $this->db->get_results($sql);
    return array_reverse($result);
  }

  /**
   * Returns the next events.
   *
   * @param int      $id      Event id
   * @param int      $num     Number of event to display
   * @return mixed            Database results
   * @todo                    Add the $recc parameter so we can get rid of the other functions
   *                          that duplicate this fonctionnality.
   */
  function getNextEvents($d, $num) {
    $sql = "SELECT * FROM `$this->mainTable` WHERE eventStartDate > '$d' AND eventRecStatus IS NULL ORDER BY eventStartDate LIMIT $num;";
    return $this->db->get_results($sql);
  }

  /**
   * Returns the first event registered.
   *
   * @param bool     $recc    If TRUE, returns also the recurring events.
   * @return mixed            The fist event. Defaults to TRUE
   */
  function getFirstEventDate($recc = true) {
    $sql = "SELECT * FROM `$this->mainTable` WHERE eventStartDate > '1960-01-01' " . (($recc==true) ? "" : "AND eventRecStatus IS NULL ") . "ORDER BY eventStartDate ASC LIMIT 1;";
    $event = $this->db->get_results($sql);
    return $event[0]->eventStartDate;

  }

  /**
   * Loads the last event registered.
   *
   * @param bool     $recc   If TRUE, returns also the recurring events.
   * @return mixed
   */
  function getLastEventDate($recc = true) {
    $sql = "SELECT * FROM `$this->mainTable` WHERE eventEndDate < '2100-01-01' " . (($recc==true) ? "" : "AND eventRecStatus IS NULL ") . "ORDER BY eventStartDate DESC LIMIT 1;";
    $event = $this->db->get_results($sql);
    return $event[0]->eventEndDate;
  }

  /**
   * Returns the lastest post
   *
   * @return mixed                The latest post.
   */
  function getLatestPost() {
    $sql = "SELECT `id` FROM `$this->postsTable` ORDER BY `id` DESC LIMIT 1;";
    return $this->db->get_results($sql);
  }

  /**
   * Returns the days that have posts.
   *
   * @param int      $m    Month to look for
   * @param int      $d    Day to look for
   * @return array         Database results
   */
  function getDaysWithPosts($m, $y) {
    $sql = "SELECT DAYOFMONTH(post_date) AS post_dom, post_title FROM `$this->postsTable` WHERE MONTH(post_date) = '$m' AND YEAR(post_date) = '$y' AND post_type = 'post' AND post_status = 'publish' AND post_date < '" . current_time('mysql') . "';";
    return $this->db->get_results($sql);
  }

  /**
   * Short description
   *
   * Long description
   *
   * @param mixed $brange     Starting date of the period
   * @param mixed $erange     Endinf date of the period
   * @return bool             TRUE when upcoming events are not recurring events?
   * @todo                    I need to understand what this does!
   */
  function getUpcomingILEvents($brange, $erange) {
    $sql = "SELECT * FROM `$this->mainTable` WHERE NOT ((eventStartDate < '$brange' AND eventEndDate < '$brange') OR (eventStartDate > '$erange' AND eventEndDate > '$erange')) ORDER BY eventStartDate;";
    $results = $this->db->get_results($sql);
    if (!$results) return false;
    $sqldate = $brange;
    //var_dump($results);
    //echo $brange, $erange,"<br />";
    while ($sqldate <= $erange) :
      foreach($results as $result) {
        if ($sqldate > $result->eventEndDate) return false;
        $recurrStatus = isset($result->eventRecStatus) ? $result->eventRecStatus : '';
        if ($recurrStatus) {
          //echo "sqldt = $sqldate";
          $recProces = $result->eventRecProces;
          $recExcept = $result->eventExceptions;
          $startDate = isset($result->eventStartDate) ? $result->eventStartDate : '';
          //echo "eventRecStatus = $recurrStatus, strtdt = $startDate, sqldt = $sqldate, proc  = $recProces<br />";
          if ($recurrStatus && $startDate) $recurrStatus = reccurEventokToDisplay($sqldate, $startDate, $recurrStatus, $recProces, $recExcept);
          //echo "eventRecStatus = $recurrStatus, strtdt = $startDate, sqldt = $sqldate, proc  = $recProces<br />";
        }
        if (!$recurrStatus) return true;
        $sqldate = date('Y-m-d', strtotime("+1 day", strtotime($sqldate)));
      }
    endwhile;
    return false;
  }
}
endif;
?>