<?php
/*
--------------------------------------------------------------------------
This file is part of the WP Events Calendar project.

For questions, help, comments, discussion, etc., please join our
forum at {@link http://www.wp-eventscalendar.com/forum}. You can
also go to Luke's ({@link http://www.lukehowelll.com}) and
Heirem's ({@link http://heirem.fr}) blogs.

WP Events Calendar is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.   See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
--------------------------------------------------------------------------
*/

/**
 * This file contains the WP Events Calendar Large Calendar Manager class.
 *
 * @internal      Long description to be done. Or maybe we don't need it
 *                since we the class will be commented.
 *
 * @package       WP-Events-Calendar
 * @subpackage    Core
 * @author        
 *                - Luke Howell <luke@wp-eventscalendar.com>
 *                - Brad Bodine <brad@wp-eventscalendar.com>
 *                - Ren MALKA <heirem@wp-eventscalendar.com>
 * @link          
 *                - http://wp-eventscalendar.com/
 *                - http://www.lukehowell.com
 *                - http://myboxtool.com/
 *                - http://heirem.fr
 *                - http://laplix.com
 *                - http://www.gwathneydesign.com/
 * @since         7.0.0
 * @copyright     
 *                - Copyright (c) 2007-2009 Luke Howell
 *                - Copyright (c) 2007-2009 Brad Bodine
 *                - Copyright (c) 2008-2009 Ren Malka
 *                - Copyright (c)      2009 Louis Lapointe
 *                - Copyright (c)      2009 Coe Gwathney
 * @license       GPLv3 {@link http://www.gnu.org/licenses/gpl}
 * @filesource
 *
 */ 

if(!class_exists("EC_LCalendar")) :

/**
 * Display and manage the Large Calendar
 *
 * @internal Long description to be done.
 *
 * @package       WP-Events-Calendar
 * @subpackage    Core
 * @since         7.0.0
 */
class EC_LCalendar {

   /**
    * Holds the EC_DB database object
    * @var object
    */
   var $db;

   /**
    * Initialization.
    *
    * It just instanciate the EC_DB object.
    */
   function EC_LCalendar() {
      $this->db = new EC_DB();
   }
   /**
    * Displays the large calendar.
    *
    * Displays the events related to the $year and $month parameters provided. 
    * If the $before_large_calendar contains some data, it will be displayed
    * prior to the calendar. This enables us to print a title or a description.
    *
    *
    * @since         6.0
    *
    * @param int     $year                   the year to display
    * @param int     $month                  the month to display
    * @param string  $before_large_calendar  HTML to display before outputing the calendar.
    *                                        Defaults to an empty string.
    * @param array   $days                   Not used.
    * @param int     $day_name_length        Length if day names. These will be shown if
    *                                        length is greater that zero. If length is smaller
    *                                        than 4, a substring of that length is used, otherwise
    *                                        the whole name is used. Defauts to 7.
    *
    * @global array                          Contains the localized days name.
    * @global array                          Contains the localized months name.
    *
    * @todo          Seems that $day_name_length is overwritten by an option so it may not be
    *                pertinent anymoe. So maybe we should deprecate it od even remove the parameter.
    * @todo          $days is not used. Will it be later or should we remove it?
    * @todo          This function uses inline CSS. This should be move to the stylesheet.
    * @todo          the variable $option is used before it is read. get_option() should be called
    *                immediately upon entering the method.
    *
    * @access        public
    */
  function displayLarge($year, $month, $before_large_calendar = "", $days = array(), $day_name_length = 7 ) {
		global $ec_WeekdayNames, $ec_MonthNames;
		// Option : Is the CSS adapted for your site ?
		$adaptedCSS = $options['adaptedCSS'];
		// If not we prepare the CSS style for ToDay
		$todayCSS = '';
		if (!$adaptedCSS) $todayCSS = isset($options['todayCSS']) && !empty($options['todayCSS']) ? $options['todayCSS'] : 'background-color:#9BA9CF; color:#FFF;';
    $first_of_month = gmmktime(0,0,0,$month,1,$year);
	  $day_names = array();
	  for($n=0,$t=(3+WPECFDW)*86400; $n<7; $n++,$t+=86400) //January 4, 1970 was a Sunday
	    $day_names[$n] = $ec_WeekdayNames[intval(gmdate('w',$t))];
	  list($month, $year, $month_name, $weekday) = explode(',',gmstrftime('%m,%Y,%B,%w',$first_of_month));
	  $weekday = ($weekday + 7 - WPECFDW) % 7; //adjust for $first_day
		$titMonth = $ec_MonthNames[intval($month)];
		$calendar = '<div id="calendar_wrapLarge">'."\n".'<h2 style="text-align:center;">'."\n\t".'<table cellspacing="0" cellpadding="0" width="100%" border="0">'."\n\t";
		$calendar .='<tr>'."\n\t\t".'<td width="25%" align="left"><span id="EC_previousMonthLarge"></span></td>'."\n\t\t";
		$calendar .='<td width="23%" align="right">'.$titMonth.'</td>'."\n\t\t".'<td width="18" align="center"><span id="EC_ajaxLoader"></span></td>'."\n\t\t";
		$calendar .='<td width="55" align="left">'.$year.'</td>'."\n\t\t".'<td width="25%" align="right"><span id="EC_nextMonthLarge"></span></td>'."\n\t".'</tr>'."\n\t".'</table>'."\n".'</h2>';
    $calendar .= "\n".'<table summary="Large Event Calendar" id="wp-calendarLarge">'."\n".'<thead><tr>'."\n";
    // Following two lines will get the length of day names - Ron
    $options = get_option('optionsEventsCalendar');
    $day_name_length = $options['daynamelengthLarge'];
	  if($day_name_length){ //if the day names should be shown ($day_name_length > 0)
		  //if day_name_length is >3, the full name of the day will be printed
		  foreach($day_names as $d)
			  $calendar .= '<th abbr="'.$d.'" scope="col" title="'.$d.'">'.($day_name_length < 4 ? ec_utf8_substr($d,0,$day_name_length) : $d).'</th>'."\n";
	  }
	  $calendar .= '</tr></thead>'."\n".'<tbody><tr>'."\n";
	  if($weekday > 0) $calendar .= '<tbody><tr><td colspan="'.$weekday.'" class="pad">&nbsp;</td>';
	  for($day=1,$days_in_month=gmdate('t',$first_of_month); $day<=$days_in_month; $day++,$weekday++){
		  if($weekday == 7){
			  $weekday   = 0; //start a new week
			  $calendar .= "</tr>\n<tr>";
		  }
			$dayID = '';
			if ("$month/$day/$year" == date('m/j/Y'))
        $dayID = (!$adaptedCSS) ? ' id="todayLarge" style="'.$todayCSS.'" ' : ' id="todayLarge" ';
		  $calendar .= '<td'.$dayID.'><div class="dayHead">'.$day.'</div><div id="events-calendar-'.$day.'Large"></div></td>'."\n";
	  }
	  if($weekday != 7) $calendar .= '<td colspan="'.(7-$weekday).'" class="pad">&nbsp;</td>'; //remaining "empty" days
	  $calendar .= "\n</tr></tbody></table>\n".'<script type="text/javascript">'."\n".'// <![CDATA['."\n";
		$calendar .= '  jQuery.noConflict();'."\n".'  (function($) {'."\n".'   ecd.jq(document).ready(function() {'."\n";
		echo $before_large_calendar;
		echo $calendar;
	  $this->calendarDataLarge($month, $year);
	  echo '   });'."\n".'  })(jQuery);'."\n".'//]]>'."\n".'</script>'."\n".'</div>';	  
	}
  function displayTBLarge() {
      echo "
<!DOCTYPE html PUBLIC '-//W3C//DTD XHTML 1.0 Transitional//EN' 'http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd'>
<html xmlns='http://www.w3.org/1999/xhtml'>
<head profile='http://gmpg.org/xfn/1'>
<meta http-equiv='Content-Type' content='text/html; charset=UTF-8' />
<script type='text/javascript' src='http://localhost/heirem/wp-includes/js/jquery/jquery.js?ver=1.2.6'></script>
<script type='text/javascript' src='http://localhost/heirem/wp-content/plugins/events-calendar/js/jquery.bgiframe.js?ver=2.1'></script>
<script type='text/javascript' src='http://localhost/heirem/wp-content/plugins/events-calendar/js/jquery.dimensions.js?ver=1.0b2'></script>
<script type='text/javascript' src='http://localhost/heirem/wp-content/plugins/events-calendar/js/jquery.tooltip.min.js?ver=1.3'></script>
<script type='text/javascript' src='http://localhost/heirem/wp-content/plugins/events-calendar/js/jquery.event.drag-1.0.js?ver=1.0'></script>
<script type='text/javascript' src='http://localhost/heirem/wp-includes/js/thickbox/thickbox.js?ver=3.1-20080430'></script>
<script type='text/javascript'>
	// <![CDATA[
	var ecd = {};
	ecd.jq= jQuery.noConflict(false);
  //]]>
</script>
<link type='text/css' rel='stylesheet' href='http://localhost/heirem/wp-includes/js/thickbox/thickbox.css' />
<link type='text/css' rel='stylesheet' href='http://localhost/heirem/wp-content/plugins/events-calendar/css/events-calendar.css' />
</head>
<body>
      ";
      $this->displayLarge(date('Y'), date('m'));
  }	
   /**
    * Loads the data and builds the HTML.
    *
    * @internal Long description to be done.
    *
    * @param int $y        the year of the month we want to display.
    * @param int $m        we want to display the events of this month.
    *
    * @global array        Localized months name.
    * @global string       
    * @access private
    */
	function calendarDataLarge($m, $y) {
		global $ec_MonthNames, $ec_WeekdayString;
    global $current_user;
    $options = get_option('optionsEventsCalendar');
    $lastDay = date('t', mktime(0, 0, 0, $m, 1, $y));
    for($d = 1; $d <= $lastDay; $d++):
      $sqldate = date('Y-m-d', mktime(0, 0, 0, $m, $d, $y));
      foreach($this->db->getDaysEvents($sqldate) as $e) :
          // Change: Output has to be after foreach and before the if statement.
          $output = '';$recb = '';
          if (($e->accessLevel == 'public') || (current_user_can($e->accessLevel))) {
            $recurrStatus = isset($e->eventRecStatus) ? $e->eventRecStatus : '';
            $recStatusFlag = $recurrStatus ;
            $recProces = $e->eventRecProces;
            $recExcept = $e->eventExceptions;            
            $startDate = isset($e->eventStartDate) ? $e->eventStartDate : '';
            $endDate = isset($e->eventEndDate) ? $e->eventEndDate : '';            
            if ($recurrStatus && $startDate) $recurrStatus = reccurEventokToDisplay($sqldate, $startDate, $recurrStatus, $recProces, $recExcept);
            if (!$recurrStatus) {
              $id = "$d-$e->id";
              $title = $e->eventTitle;
              $description = preg_replace('#\r?\n#', '<br />', $e->eventDescription);
              $location = isset($e->eventLocation) && !empty($e->eventLocation) ? $e->eventLocation : '';
              $linkout = isset($e->eventLinkout) && !empty($e->eventLinkout) ? $e->eventLinkout : '';
              $startTime = $e->eventStartTime;
              $endTime = $e->eventEndTime;
              $PostID = isset($e->postID) ? $e->postID : '';
              list($ec_startyear, $ec_startmonth, $ec_startday) = explode('-', $startDate);
              $startDate = date($options['dateFormatLarge'], mktime($ec_starthour, $ec_startminute, $ec_startsecond, $ec_startmonth, $ec_startday, $ec_startyear));
              list($ec_endyear, $ec_endmonth, $ec_endday) = explode('-', $endDate);
              $endDate = date($options['dateFormatLarge'], mktime($ec_endhour, $ec_endminute, $ec_endsecond, $ec_endmonth, $ec_endday, $ec_endyear));
              if ((!is_null($startTime) && !empty($startTime))) {
                list($ec_starthour, $ec_startminute, $ec_startsecond) = explode(":", $startTime);
                $startTime = date($options['timeFormatLarge'], mktime($ec_starthour, $ec_startminute, $ec_startsecond, $ec_startmonth, $ec_startday, $ec_startyear));
              }
              if (($endTime != null) && (!empty($endTime))) {
                list($ec_endhour, $ec_endminute, $ec_endsecond) = explode(":", $endTime);
                $endTime = date($options['timeFormatLarge'], mktime($ec_endhour, $ec_endminute, $ec_endsecond, $ec_endmonth, $ec_endday, $ec_endyear));
              }
              if ($recStatusFlag > 0) {
                $output .= '<p style="text-align:center;font-weight:bold;background-color:black;color:white;">';
                $output .= _c('Reccur. Event','events-calendar');
                $output .= "</p>";
              }              
              if (!empty($title) && !is_null($title))
                $output .= '<strong><center><span style="margin:1px;padding:1px;">'.$title.'</span></center></strong>';
              if (!empty($location) && !is_null($location))
                $output .= "<strong>"._c('Location','events-calendar').": </strong>$location<br />";
              if (!empty($description) && !is_null($description))
                $output .= "<strong>"._c('Description','events-calendar').": </strong>$description<br />";
              if ($recStatusFlag > 0) {
                $output .= "<strong>"._c('Recurrence','events-calendar').": </strong>";
                switch ($recStatusFlag) {
                  case 1: // A day in the month
                    $recparam1 = $recProces;
                    $output .= sprintf(__('Every %s / month','events-calendar'),$recparam1);
                    if (!$recb) $recb = 'style=\"border-width:2px; border-color:blue; border-style:outset; padding:1px;\"';
                    break;
                  case 2: // Every X days
                    $recparam1 = $recProces;
                    $output .= sprintf(__('Every %s days','events-calendar'),$recparam1);
                    if (!$recb) $recb = 'style=\"border-width:2px; border-color:magenta; border-style:outset; padding:1px;\"';
                    break;
                  case 3: // Every some weekdays
                    $recparam1 = '';
                    $recProces = unserialize($recProces);
                    foreach ($recProces as $value) $recparam1 .= substr($ec_WeekdayString, $value, 1)." ";
                    $output .= sprintf(__('Every %s','events-calendar'),$recparam1);
                    if (!$recb) $recb = 'style=\"border-width:2px; border-color:brown; border-style:outset; padding:1px;\"';
                    break;
                  case 4: // Every some weeks in the month
                    $recparam1 = '';
                    $recProces = unserialize($recProces);
                    foreach ($recProces as $value) {
                     if ($value == '5') $recparam1 .= _c('last','events-calendar'); else $recparam1 .= "#".$value." ";
                    }
                    $output .= sprintf(__('Every %s week','events-calendar'),$recparam1);
                    if (!$recb) $recb = 'style=\"border-width:2px; border-color:gold; border-style:outset; padding:1px;\"';
                    break;
                  case 6: // Every X days in somes weeks in the month
                    $recparam2 = '';
                    list($recparam1, $recpartmp)  = explode('|', $recProces);
                    $recpartmp = unserialize($recpartmp);
                    foreach ($recpartmp as $value) {
                     if ($value == '5') $recparam2 .= _c('last','events-calendar'); else $recparam2 .= "#".$value." ";
                    }
                    $output .= sprintf(__('Every %s days, %s week','events-calendar'),$recparam1,$recparam2);
                    if (!$recb) $recb = 'style=\"border-width:2px; border-color:green; border-style:outset; padding:1px;\"';
                    break;
                  case 7: // Every some weekdays in somes weeks in the month
                    $recparam1 = ''; $recparam2 = '';
                    list($recpartmp, $recpartmp1)  = explode('|', $recProces);
                    $recpartmp = unserialize($recpartmp);
                    $recpartmp1 = unserialize($recpartmp1);
                    foreach ($recpartmp as $value) $recparam1 .= substr($ec_WeekdayString, $value, 1)." ";
                    foreach ($recpartmp1 as $value) {
                     if ($value == '5') $recparam2 .= _c('last','events-calendar'); else $recparam2 .= "#".$value." ";
                    }
                    $output .= sprintf(__('Every %s, %s week','events-calendar'),$recparam1,$recparam2);
                    if (!$recb) $recb = 'style=\"border-width:2px; border-color:aqua; border-style:outset; padding:1px;\"';
                    break;
                }
                $output .= "<br />";
              }                
              if ($startDate != $endDate) // && (!is_null($startDate) || !empty($startDate)) && (!is_null($endDate) || !empty($endDate)))
                $output .= "<strong>"._c('Start Date','events-calendar').": </strong>$startDate<br />";
              if (!empty($startTime) || !is_null($startTime))
                $output .= "<strong>"._c('Start Time','events-calendar').": </strong>$startTime<br />";
              if ($startDate != $endDate) // && (!is_null($endDate) || !empty($endDate)))
                $output .= "<strong>"._c('End Date','events-calendar').": </strong>$endDate<br />";
              if (!empty($endTime) && !empty($startTime) || !is_null($endTime) && !is_null($startTime))
                $output .= "<strong>"._c('End Time','events-calendar').": </strong>$endTime<br />";
              // Link outside the site if the link exist : priority on the PostID link
              if ($linkout != '') {
                $output .= "<strong>"._c('Link out','events-calendar')."</strong> :".substr($linkout,0,19)."<br />";;
                $titlinked = "<a href=\"".$linkout."\" target=\"_blanck\"><strong>$title</strong></a>";
              } elseif ($PostID != '') { // Link to a post when exist
                $titlinked = "<a href=\"" . get_permalink($PostID) . "\"><strong>$title</strong></a>";
              } else {
                $titlinked = "<strong>$title</strong>";
              }
              $cursor = (($PostID != '') OR ($linkout != '')) ? 'pointer' : 'default';
            }
          }
        if($output != ''):
      ?>
      ecd.jq('#events-calendar-<?php echo $d;?>Large').append('<span class="event-block" id="events-calendar-<?php echo $id;?>Large" <?php echo $recb;?> ><?php echo $titlinked;?></span>');
      ecd.jq('#events-calendar-<?php echo $id;?>Large').attr('title', '<?php echo $output;?>');
        ecd.jq('#events-calendar-<?php echo $id;?>Large').mouseover(function() {
          ecd.jq(this).css('cursor', '<?php echo $cursor; ?>');
        });
      ecd.jq('#events-calendar-<?php echo $id;?>Large').tooltip({
        track: true,
        delay: 0,
        showURL: false,
        opacity: 1,
        fixPNG: true,
        showBody: " - ",
        // extraClass: "pretty",
        top: -15,
        left: 15
      });
      <?php
        endif;
      endforeach;
    endfor;
    $img_plmonth = EVENTSCALENDARIMAGESURL.'/plmonth.gif';
    $img_nlmonth = EVENTSCALENDARIMAGESURL.'/nlmonth.gif';
    // Vertical Previous Month List
    $selVpMonthList = "<span id=\"EC_VpLMonthList\"><img src=\"$img_plmonth\"/>&nbsp;</span><ul>";
    if ($m == 1) {$lst_month = 12; $lst_year = $y - 1;} else {$lst_month = $m - 1; $lst_year = $y;}
    for ($i=1;$i<13;$i++ ) {
      $lst_month--;
      if ($lst_month < 1) {$lst_month = 12; $lst_year -= 1;}
      if ($lst_year == 1969) break;
    	$selVpMonthList .= "<li id=\"itemLVpMonth-$lst_month-$lst_year\">".$ec_MonthNames[$lst_month]."&nbsp;".$lst_year."</li>";
    }
    $selVpMonthList .= '</ul><span id=\"EC_pMonthLink\">'.ucfirst(get_incrMonth($m-1,1)).'</span>';
    // Vertical Next Month List
    $selVnMonthList = '<span id="EC_nMonthLink">'.ucfirst(get_incrMonth($m+1,1))."</span>&nbsp;<span id=\"EC_VnLMonthList\"><img src=\"$img_nlmonth\"/></span><ul>";
    if ($m == 12) {$lst_month = 1; $lst_year = $y + 1;} else {$lst_month = $m + 1; $lst_year = $y;}
    for ($i=1;$i<13;$i++ ) {
      $lst_month++;
      if ($lst_month > 12) {$lst_month = 1; $lst_year++;}
    	$selVnMonthList .= "<li id=\"itemLVnMonth-$lst_month-$lst_year\">".$ec_MonthNames[$lst_month]."&nbsp;".$lst_year."</li>";
    }
    $selVnMonthList .= '</ul>';
    ?>
      function Go_To_LMonth(mtarget,ytarget) {
        ecd.jq('#EC_ajaxLoader').empty();
        ecd.jq('#EC_ajaxLoader').append(' <img src="<?php echo EVENTSCALENDARIMAGESURL . '/ajax-loader.gif';?>" />');
        ecd.jq.get("<?php bloginfo('wpurl');?>/index.php?",
        {EC_action: "switchMonthLarge", EC_month: mtarget, EC_year: ytarget},
        function(data) {
          ecd.jq('#calendar_wrapLarge').empty();
          ecd.jq('#calendar_wrapLarge').append(ecd.jq(data).html());
        });
      }
      ecd.jq('#EC_ajaxLoader').append(' <img src="<?php echo EVENTSCALENDARIMAGESURL . '/space.gif';?>" />');
      ecd.jq('#EC_previousMonthLarge').append('<?php echo $selVpMonthList;?>');
      ecd.jq('#EC_VpLMonthList').attr('title', '<?php _e("Click to get a list of previous months","events-calendar");?>');
      ecd.jq('#EC_nextMonthLarge').prepend('<?php echo $selVnMonthList;?>');
      ecd.jq('#EC_VnLMonthList').attr('title', '<?php _e("Click to get a list of next months","events-calendar");?>');
      ecd.jq('#EC_VpLMonthList').tooltip({track: true, delay: 0, top: 15, left: 20, extraClass: "gotomonth"});
      ecd.jq('#EC_VnLMonthList').tooltip({track: true, delay: 0, top: 15, left: 20, extraClass: "gotomonth"});
      ecd.jq('#EC_pMonthLink').mouseover(function() {
        ecd.jq(this).css('cursor', 'pointer');
      });
      ecd.jq('#EC_nMonthLink').mouseover(function() {
        ecd.jq(this).css('cursor', 'pointer');
      });
    	ecd.jq("#EC_previousMonthLarge li,#EC_previousMonthLarge td").click(function(){
        var selmonth = $(this).attr("id").split('-');
        ecd.jq("#EC_previousMonthLarge ul").fadeOut("normal");
        Go_To_LMonth(selmonth[1],selmonth[2]);
    	});
    	ecd.jq("#EC_nextMonthLarge li,#EC_nextMonthLarge td").click(function(){
        var selmonth = $(this).attr("id").split('-');
        ecd.jq("#EC_nextMonthLarge ul").fadeOut("normal");
        Go_To_LMonth(selmonth[1],selmonth[2]);
    	});
      ecd.jq('#EC_previousMonthLarge img').click(function() {
        ecd.jq("#EC_nextMonthLarge ul").fadeOut("normal");
        if(ecd.jq.browser.msie) {
          var offset = ecd.jq("#calendar_wrapLarge td").height();
          ecd.jq("#EC_previousMonthLarge ul").css({marginTop:offset+"px"});
          offset = - ecd.jq("#calendar_wrapLarge td").height() / 4;
          ecd.jq("#EC_previousMonthLarge ul").css({marginLeft:offset+"px"});
        }
        ecd.jq("#EC_previousMonthLarge ul").slideToggle("normal");
        return false;
      });
      ecd.jq('#EC_nextMonthLarge img').click(function() {
        ecd.jq("#EC_previousMonthLarge ul").fadeOut("normal");
        if(ecd.jq.browser.msie) {
          var offset = ecd.jq("#calendar_wrapLarge td").height();
          ecd.jq("#EC_nextMonthLarge ul").css({marginTop:offset+"px"});
          offset = 23 - ecd.jq("#calendar_wrapLarge td").width() ;
          ecd.jq("#EC_nextMonthLarge ul").css({marginLeft:offset+"px"});
        } else {
          var wpcl = ecd.jq("#calendar_wrapLarge td").width();
          var lstl = ecd.jq("#EC_nextMonthLarge ul").width();
          var offset = wpcl - lstl - 13;
          ecd.jq("#EC_nextMonthLarge ul").css({marginLeft:offset+"px"});
        }
        ecd.jq("#EC_nextMonthLarge ul").slideToggle("normal");
        return false;
      });
      ecd.jq('#EC_pMonthLink').click(function() {
        Go_To_LMonth(<?php echo get_incrMonth($m-1);?>,<?php echo ($m==1) ? ($y-1) : $y;?>);
      });
      ecd.jq('#EC_nMonthLink').click(function() {
        Go_To_LMonth(<?php echo get_incrMonth($m+1);?>,<?php echo ($m==12) ? ($y+1) : $y;?>);
      });
    	ecd.jq('body').click(function() {
    	 ecd.jq("#EC_previousMonthLarge ul").fadeOut("normal");
    	 ecd.jq("#EC_nextMonthLarge ul").fadeOut("normal");
    	});
    <?php
  }
}
endif;  
?>
