<?php
/*
--------------------------------------------------------------------------
This file is part of the WP Events Calendar project.

For questions, help, comments, discussion, etc., please join our
forum at {@link http://www.wp-eventscalendar.com/forum}. You can
also go to Luke's ({@link http://www.lukehowelll.com}) and
Heirem's ({@link http://heirem.fr}) blogs.

WP Events Calendar is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.   See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
--------------------------------------------------------------------------
*/

/**
 * This file contains the WP Events Calendar EC_Options class.
 *
 * @internal      Long description to be done.
 *
 * @package       WP-Events-Calendar
 * @subpackage    Core
 * @author        
 *                - Luke Howell <luke@wp-eventscalendar.com>
 *                - Brad Bodine <brad@wp-eventscalendar.com>
 *                - Ren MALKA <heirem@wp-eventscalendar.com>
 * @link          
 *                - http://wp-eventscalendar.com/
 *                - http://www.lukehowell.com
 *                - http://myboxtool.com/
 *                - http://heirem.fr
 *                - http://laplix.com
 *                - http://www.gwathneydesign.com/
 * @since         6.0
 * @copyright     
 *                - Copyright (c) 2007-2009 Luke Howell
 *                - Copyright (c) 2007-2009 Brad Bodine
 *                - Copyright (c) 2008-2009 Ren Malka
 *                - Copyright (c)      2009 Louis Lapointe
 *                - Copyright (c)      2009 Coe Gwathney
 * @license       GPLv3 {@link http://www.gnu.org/licenses/gpl}
 * @filesource
 *
 * @todo Tis file doesn't seem to be used and duplicated the class name
 *       from ec_options.class.php. Should it be deleted or renamed?
 */ 
if(!class_exists('EC_Options')):

/**
 * This class is used by WPEC to setup and display the calendar options.
 *
 * @internal Long description to be done.
 *
 * @package       WP-Events-Calendar
 * @subpackage    Core
 * @since         {@internal not documented yet}
 */
class EC_Options { 

   /**
    * Displays the calendar options and save them when they are submitted.
    *
    * The function first read the current options from the database.
    * If they don't exist yet, they are initialized.
    *
    * Then it checks if the form was submitted and if so saves them to
    * database.
    *
    * Finally, the form is displayed so the user can adjust the options
    */
  function calendarOptions() {
    $options = get_option('optionsEventsCalendar');
    if(!is_array($options)) {
      $options = array();
      $options['dateFormatWidget'] = 'm-d';
      $options['timeFormatWidget'] = 'h:i a';
      $options['dateFormatLarge'] = 'n/j/Y';
      $options['timeFormatLarge'] = 'h:i a';
      $options['adaptedCSS'] = '';
      $options['todayCSS'] = 'border:thin solid blue;font-weight: bold;';
      $options['dayHasEventCSS'] = 'color:red';
      $options['timeStep'] = '30';
      $options['daynamelength'] = '3';
      $options['daynamelengthLarge'] = '3';
      $options['jqueryextremstatus'] = 'false';
    }
    if ( $_POST['optionsEventsCalendarSubmitted'] ) {
      //echo var_dump($_POST);
      $options['dateFormatWidget'] = isset($_POST['dateFormatWidget']) && !empty($_POST['dateFormatWidget']) ? $_POST['dateFormatWidget'] : 'm-d';
      $options['timeFormatWidget'] = isset($_POST['timeFormatWidget']) && !empty($_POST['timeFormatWidget']) ? $_POST['timeFormatWidget'] : 'g:i a';
      $options['dateFormatLarge'] = isset($_POST['dateFormatLarge']) && !empty($_POST['dateFormatLarge']) ? $_POST['dateFormatLarge'] : 'n/j/Y';
      $options['timeFormatLarge'] = isset($_POST['timeFormatLarge']) && !empty($_POST['timeFormatLarge']) ? $_POST['timeFormatLarge'] : 'g:i a';
      $options['timeStep'] = isset($_POST['timeStep']) && !empty($_POST['timeStep']) ? $_POST['timeStep'] : '30';
      $options['adaptedCSS'] = isset($_POST['adaptedCSS']) ? $_POST['adaptedCSS'] : '';
      $options['todayCSS'] = isset($_POST['todayCSS']) && !empty($_POST['todayCSS']) ? $_POST['todayCSS'] : 'border:thin solid blue;font-weight: bold;';
      $options['dayHasEventCSS'] = isset($_POST['dayHasEventCSS']) && !empty($_POST['dayHasEventCSS']) ? $_POST['dayHasEventCSS'] : 'color:red;';
      $options['daynamelength'] = isset($_POST['daynamelength']) && !empty($_POST['daynamelength']) ? $_POST['daynamelength'] : '3';
      $options['daynamelengthLarge'] = isset($_POST['daynamelengthLarge']) && !empty($_POST['daynamelengthLarge']) ? $_POST['daynamelengthLarge'] : '3';
      $options['jqueryextremstatus'] = isset($_POST['jqxstatus']) ? $_POST['jqxstatus'] : 'false';
      $options['accessLevel'] = $_POST['EC_accessLevel'];

      update_option('optionsEventsCalendar', $options);
    }
?>
    <div class="wrap"><h2 style="border:none;margin-top:12px;"><?php _e('Events Calendar Options','events-calendar');?></h2></div>
    <form name="optionsEventsCalendar" method="post" action="?page=events-calendar-options" onLoad="">
      <p class="submit">
        <input type="submit" name="submit" value="<?php _e('Events Calendar Update Options','events-calendar');?> &raquo;"/>
      </p>
      <table summary="Edit Form 1" class="ecform-table" width="100%" cellspacing="2" cellpadding="5">
        <tr>
          <th width="33%" scope="row" valign="center"><label for="EC_accessLevel"><?php _e('Access Level','events-calendar');?></label></th>
          <td width="67%">
            <select name="EC_accessLevel" id="accessLevel">
              <option value="level_10" <?php if($options['accessLevel'] == 'level_10') echo 'selected="selected"';?>><?php _e('Administrator','events-calendar');?></option>
              <option value="level_7" <?php if($options['accessLevel'] == 'level_7') echo 'selected="selected"';?>><?php _e('Editor','events-calendar');?></option>
              <option value="level_2" <?php if($options['accessLevel'] == 'level_2') echo 'selected="selected"';?>><?php _e('Author','events-calendar');?></option>
              <option value="level_1" <?php if($options['accessLevel'] == 'level_1') echo 'selected="selected"';?>><?php _e('Contributor','events-calendar');?></option>
              <option value="level_0" <?php if($options['accessLevel'] == 'level_0') echo 'selected="selected"';?>><?php _e('Subscriber','events-calendar');?></option>
            </select>
          </td>
        </tr>
        </table>
        <table summary="Edit Form 2" class="ecform-table" width="100%" cellspacing="2" cellpadding="5">
        <tr>
          <th><label><?php _e('Date/Time Formatting(see','events-calendar');?> <a href="http://us2.php.net/date" target="_blank">PHP Date</a>) :</label></th>
          <td ></td>
        </tr>
        <tr>
          <th width="33%" scope="row" valign="center"><label for="dateFormatWidget"><?php _e('Widget Calendar Dates','events-calendar');?></label></th>
          <td width="67%"><input type="text" name="dateFormatWidget" id="dateFormatWidget" value="<?php echo $options['dateFormatWidget'];?>"/></td>
        </tr>
        <tr>
          <th width="33%" scope="row" valign="center"><label for="timeFormatWidget"><?php _e('Widget Calendar Times','events-calendar');?></label></th>
          <td width="67%"><input type="text" name="timeFormatWidget" id="timeFormatWidget" value="<?php echo $options['timeFormatWidget'];?>"/></td>
        </tr>
        <tr>
          <th width="33%" scope="row" valign="center"><label for="dateFormatLarge"><?php _e('Large Calendar Dates + Thickbox Title Date format','events-calendar');?></label></th>
          <td width="67%"><input type="text" name="dateFormatLarge" id="dateFormatLarge" value="<?php echo $options['dateFormatLarge'];?>"/></td>
        </tr>
        <tr>
          <th width="33%" scope="row" valign="center"><label for="timeFormatLarge"><?php _e('Large Calendar Times','events-calendar');?></label></th>
          <td width="67%"><input type="text" name="timeFormatLarge" id="timeFormatLarge" value="<?php echo $options['timeFormatLarge'];?>"/></td>
        </tr>
        <tr>
          <th width="33%" scope="row" valign="center"><label for="timeStep"><?php _e('Step Increment for Time Selector (in minutes)','events-calendar');?></label></th>
          <td width="67%"><input type="text" name="timeStep" id="timeStep" value="<?php echo $options['timeStep'];?>"/></td>
        </tr>
        <tr>
          <th width="33%" scope="row" valign="center"><label for="adaptedCSS"><?php _e('I have adapted the Events-Calendar stylesheet (checked = yes)','events-calendar');?></label></th>
          <td width="67%"><input type="checkbox" <?php echo ($options['adaptedCSS']==true) ? "checked " : "";?>name="adaptedCSS" id="EC_adaptedCSS" value="on"/></td>
        </tr>
        </table>
        <span id="switchCSSoptions">
        <table summary="Edit Form 3" class="ecform-table" width="100%" cellspacing="2" cellpadding="5">
        <tr>
          <th width="33%" scope="row" valign="center" id="EC_todayCSS"><label for="todayCSS"><?php _e('CSS for Today Date','events-calendar');?></label></th>
          <td width="67%"><input type="text" name="todayCSS" id="EC_todayCSS" value="<?php echo $options['todayCSS'];?>"/></td>
        </tr>
        <tr>
          <th width="33%" scope="row" valign="center" id="EC_dayHasEventCSS"><label for="dayHasEventCSS"><?php _e('CSS for Day With Events','events-calendar');?></label></th>
          <td width="67%"><input type="text" name="dayHasEventCSS" id="EC_dayHasEventCSS" value="<?php echo $options['dayHasEventCSS'];?>"/></td>
        </tr>
        </table>
        </span>
        <table summary="Edit Form4" class="ecform-table" width="100%" cellspacing="2" cellpadding="5">
        <tr>
          <th width="33%" scope="row" valign="center"><label for="daynamelength"><?php _e('Length of day names in Widget Calendar','events-calendar');?></label></th>
          <td width="67%"><input type="text" name="daynamelength" id="EC_daynamelength" value="<?php echo $options['daynamelength'];?>"/></td>
        </tr>
        <th width="33%" scope="row" valign="center"><label for="daynamelengthLarge"><?php _e('Length of day names in Large Calendar','events-calendar');?></label></th>
          <td width="67%"><input type="text" name="daynamelengthLarge" id="EC_daynamelengthLarge" value="<?php echo $options['daynamelengthLarge'];?>"/></td>
        </tr>
        <tr>
          <th width="33%" scope="row" valign="center"><label for="jqxstatus"><?php _e('jQuery Extrem Protection (checked = yes)','events-calendar');?></label></th>
          <td width="67%"><input type="checkbox" <?php echo ($options['jqueryextremstatus']=="true") ? " checked" : "";?> name="jqxstatus" id="EC_jqxstatus" value="true"/> <?php _e('(Check if you don\'t see the Tooltips)','events-calendar');?></td>
        </tr>
      </table>
      <input type="hidden" name="optionsEventsCalendarSubmitted" value="1"/>
      <p class="submit">
        <input type="submit" name="submit" value="<?php _e('Update Options','events-calendar');?> &raquo;"/>
      </p>
    </form>
    <script type="text/javascript">
    // <![CDATA[
      jQuery.noConflict();
      jQuery("form[@name='optionsEventsCalendar']").ready(function () {
          if (jQuery("#EC_adaptedCSS").is(":checked")) {
            jQuery("#switchCSSoptions").hide("slow");
          } else {
            jQuery("#switchCSSoptions").show("slow");
          };
      });
      jQuery("#EC_adaptedCSS").click(function () {
          if (jQuery("#EC_adaptedCSS").is(":checked")) {
            jQuery("#switchCSSoptions").hide("slow");
          } else {
            jQuery("#switchCSSoptions").show("slow");
          };
      });
      jQuery(document).ready(function() {
          jQuery("a[@href='#addEventform']").hide();
      })(jQuery);
    //]]>
    </script>
<?php
  }
}
endif;
?>
